*****************************************************************************************************
**** Long-term and lasting impacts of personal initiative training on entrepreneurial success   *****
*****************************************************************************************************

**** This file replicates the tables and figures
**** See MasterLongRun.do for setting globals and directories
*** Analysis is in Stata version 18.0
 
	clear all
	set maxvar 32000
		
		
		
		
			
	********************************************************************************
	****** Figures  ****************************************************************
	********************************************************************************
	
	********************************************************************************
	*** Figure 1: Trajectory of Means by Treatment Status **************************
	********************************************************************************
	
	*** Figure 1A: Survival
	use "$final/Togoanalysisdata.dta", clear
	
preserve
keep id_ent survival2013 survival2016 survival2021 assign_group
reshape long survival, i(id_ent) j(year)
gen survival_ent=survival if assign_group==2
gen survival_man=survival if assign_group==1
gen survival_con=survival if assign_group==3

label var survival "Proportion of Firms Surviving"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar survival, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.2f) graphopts(title("A: Survival") xtitle("") ytitle("Business Survival")  graphregion(color(white)) ylabel(0(0.2)1) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(0.05)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig_1a.gph", replace	
restore
	
   *** Figure 1B: Unconditional Profits all businesses  
preserve
keep id_ent a1profits2013 a1profits2016 a1profits2021 assign_group
reshape long a1profits, i(id_ent assign_group) j(year)
label var a1profits "Monthly profits in Real USD"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar a1profits, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.0f) graphopts(title("B: Profits") xtitle("") ytitle("Real Profits All Businesses (USD)") graphregion(color(white)) ylabel(0(50)350) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(50)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig_1b.gph", replace	
restore

   *** Figure 1C: Profits all businesses conditional on survival 
preserve
keep id_ent c1aprofits2013 c1aprofits2016 c1aprofits2021 assign_group
reshape long c1aprofits, i(id_ent assign_group) j(year)
label var c1aprofits "Monthly profits in Real USD"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar c1aprofits, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.0f) graphopts(title("C: Profits conditional on Survival") xtitle("") ytitle("Real Profits All Businesses (USD)") graphregion(color(white)) ylabel(0(50)350) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(60)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig_1c.gph", replace	
	graph export "$output/figures/Fig_1c.png", replace
	graph export "$output/figures/Fig_1c.pdf", replace
restore

	*** Figure 1D: Employees in Main Firm 
    ** Note: earlier rounds did not ask about employees in all firms ***

preserve
keep id_ent w_employ2013 w_employ2016 w_employ2021 assign_group
reshape long w_employ, i(id_ent assign_group) j(year)
label var w_employ "Number of Employees"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar w_employ, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.1f) graphopts(title("D: Employees") xtitle("") ytitle("Number of Employees") graphregion(color(white)) ylabel(0(1)4) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(0.5)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig_1d.gph", replace	
restore
	
**** Combine subfigures into one   
grc1leg "$output/figures/Fig_1a.gph" "$output/figures/Fig_1b.gph" "$output/figures/Fig_1c.gph" "$output/figures/Fig_1d.gph", col(2) graphregion(color(white)) legendfrom("$output/figures/Fig_1a.gph")
graph save "$output/figures/Fig_1combined.gph", replace
graph export "$output/figures/Fig_1combined.pdf", replace
graph export "$output/figures/Fig_1combined.png", replace
	
	********************************************************************************
	*** Figure 2: Profits by Gender                       **************************
	********************************************************************************
	use "$final/Togoanalysisdata.dta", clear

	*** Panel A: Means over Time
	*** Males
preserve
keep if bl_female==0
keep id_ent a1profits2013 a1profits2016 a1profits2021 assign_group
reshape long a1profits, i(id_ent assign_group) j(year)
label var a1profits "Monthly profits in Real USD"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar a1profits, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.0f) graphopts(title("Men") xtitle("") ytitle("Real Profits") graphregion(color(white)) ylabel(0(50)350) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(90)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig2am.gph", replace	
restore
*** Females
preserve
keep if bl_female==1
keep id_ent a1profits2013 a1profits2016 a1profits2021 assign_group
reshape long a1profits, i(id_ent assign_group) j(year)
label var a1profits "Monthly profits in Real USD"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar a1profits, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.0f) graphopts(title("Women") xtitle("") ytitle("Real Profits") graphregion(color(white)) ylabel(0(50)350) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(60)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig2af.gph", replace	
restore

grc1leg "$output/figures/Fig2am.gph" "$output/figures/Fig2af.gph", col(2) graphregion(color(white)) legendfrom("$output/figures/Fig2am.gph") ///
title ("A: Mean Profits by Gender and Time Period")
graph save "$output/figures/Fig2panelA.gph", replace


*** Panel B: Quantile Treatment Effects
	use "$final/Togoanalysisdata.dta", clear

clear matrix
preserve

eststo clear
keep id_ent assign_man assign_ent assign_group strata totalprof* bl_aprofit  bl_female
reshape long totalprof, i(id_ent) j(wave)

foreach var in assign_man assign_ent {
	cap drop `var'_male
	gen `var'_male=`var'*(1-bl_female)
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}
cap drop bl_aprofit_female
gen bl_aprofit_female=bl_aprofit*bl_female 
for num 1/5: gen waveX=wave==X
for num 1/5: gen waveX_female=waveX*bl_female


forval i=.05(.05) 1 {
	di `i'
		
	*SR Quantile regression:
	quietly xi: qreg2 totalprof assign_man_male assign_man_female assign_ent_male assign_ent_female bl_aprofit bl_aprofit_female bl_female wave1-wave4 wave1_female wave2_female wave3_female wave4_female if wave>=1 & wave<=4,  cluster(id_ent) q(`i')
		scalar betasrm = _b[assign_ent_male]
		scalar betasrf = _b[assign_ent_female]
		quietly test assign_ent_male==assign_ent_female 
		scalar pvalsr = r(p)
    quietly qreg2 totalprof assign_man_male assign_man_female assign_ent_male assign_ent_female bl_aprofit bl_aprofit_female bl_female if wave==5, q(`i')
		scalar betalrm = _b[assign_ent_male]
		scalar betalrf = _b[assign_ent_female]
		quietly test assign_ent_male==assign_ent_female 
		scalar pvallr = r(p)
		matrix pool_qreg = [nullmat(pool_qreg) \ `i', betasrm, betasrf, betalrm, betalrf, pvalsr, pvallr]
	}

clear
svmat pool_qreg
	ren pool_qreg1 qtile
	ren pool_qreg2 srm
	ren pool_qreg3 srf
	ren pool_qreg4 lrm
	ren pool_qreg5 lrf
	ren pool_qreg6 pvalsr
	ren pool_qreg7 pvallr
	
gen y0=0
gen Percentile=qtile*100
sort Percentile
replace y0=. if Percentile<5 | Percentile>95
gen z0=0.10
replace z0=. if Percentile<5 | Percentile>95

format srm srf lrm lrf %6.0f
format pvalsr pvallr %9.3f 

twoway (line srm Percentile if Percentile>=5 & Percentile<=95, lwidth(thick) lcolor(black) lpattern(line))   ///
	   (line srf Percentile if Percentile>=5 & Percentile<=95, lwidth(thin) lcolor(black) lpattern(dash) ) ///  
	   (line y0 Percentile if Percentile>=10 & Percentile<=95, lcolor(black)), ///
	    xlabel( 5 10 20 30 40 50 60 70 80 90 95)  ///
		title("Short-run Profits") ytitle("Impact on Monthly Profits") xtitle("Quantile") ///
		scheme(s1manual) legend(order(1 "Men" 2 "Women")) legend(rows(1))	
graph save "$output/figures/Figure2bsr.gph", replace

twoway (line lrm Percentile if Percentile>=5 & Percentile<=95, lwidth(thick) lcolor(black) lpattern(line))   ///
	   (line lrf Percentile if Percentile>=5 & Percentile<=95, lwidth(thin) lcolor(black) lpattern(dash) ) ///  
	   (line y0 Percentile if Percentile>=10 & Percentile<=95, lcolor(black)), ///
	    xlabel( 5 10 20 30 40 50 60 70 80 90 95)  ///
		title("Long-run Profits") ytitle("Impact on Monthly Profits") xtitle("Quantile") ///
		scheme(s1manual) legend(order(1 "Men" 2 "Women")) legend(rows(1))	
graph save "$output/figures/Figure2blr.gph", replace

restore
grc1leg "$output/figures/Figure2bsr.gph" "$output/figures/Figure2blr.gph", col(2) graphregion(color(white)) legendfrom("$output/figures/Figure2bsr.gph") title("B: PI Quantile Treatment Effects on Total Profits")
graph save "$output/figures/Fig2panelB.gph", replace

******* Making Figure 2 *********************************
graph combine "$output/figures/Fig2panelA.gph" "$output/figures/Fig2panelB.gph", col(1) scheme(s1manual)
graph save "$output/figures/Figure2Paper.gph", replace
graph export "$output/figures/Figure2Paper.pdf", replace
graph export "$output/figures/Figure2Paper.png", replace

	
   **********************************************************************
   **** Table 1: Impact on Profits and Sales in the Pooled Sample  ******
   ********************************************************************** 
use "$final/Togoanalysisdata.dta", clear
eststo clear
keep id_ent assign_man assign_ent assign_group strata totalprof* bl_aprofit win_bl_sales_lm win_bl_sales_lw win_bl_profits_lw bl_mprofit mainprof* ctotalprof* mainsales* totalsales5 cmainsales* ctotalsales5 bl_msales psindex* bl_psindex allincome*
* reshape into a panel
reshape long mainprof totalprof ctotalprof mainsales totalsales cmainsales ctotalsales psindex allincome, i(id_ent) j(wave)
* allow treatment effects to vary with time
foreach var of varlist assign_man assign_ent {
	gen `var'_sr=0
	replace `var'_sr=`var' if wave>=1 & wave<=4
	gen `var'_lr=0
	replace `var'_lr=`var' if wave==5
	}
* Saturated model so LR results same as when SR not included: allow coefficients on baseline variable to differ in SR and LR
foreach var of varlist bl_mprofit bl_aprofit bl_msales bl_psindex {
gen `var'_sr=0
gen `var'_lr=0
replace `var'_sr=`var' if wave>=1 & wave<=4
replace `var'_lr=`var' if wave==5
}
* allow coefficient on strata to differ in SR and LR
gen tv_strata=0
replace tv_strata=strata if wave>=1 & wave<=4
replace tv_strata=1000*strata if wave==5
distinct tv_strata

*** Column 1: Level of Profits in Past Month in Main Business
xi: areg mainprof assign_ent_sr assign_man_sr assign_ent_lr assign_man_lr bl_mprofit_sr bl_mprofit_lr i.wave, a(tv_strata) cluster(id_ent) robust
sum mainprof if assign_group==3 & wave>=1 & wave<=4
estadd scalar mean1=r(mean)
estadd scalar sd1=r(sd)
sum mainprof if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_sr=assign_ent_lr
estadd scalar p1=r(p) 
test assign_man_sr=assign_man_lr 
estadd scalar p2=r(p) 
test assign_ent_sr=assign_man_sr 
estadd scalar p3=r(p) 
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_1

*** Column 2: Level of Profits in Past Month in All Businesses
xi: areg totalprof assign_ent_sr assign_man_sr assign_ent_lr assign_man_lr bl_aprofit_sr bl_aprofit_lr i.wave, a(tv_strata) cluster(id_ent) robust
sum totalprof if assign_group==3 & wave>=1 & wave<=4
estadd scalar mean1=r(mean)
estadd scalar sd1=r(sd)
sum totalprof if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_sr=assign_ent_lr
estadd scalar p1=r(p) 
test assign_man_sr=assign_man_lr 
estadd scalar p2=r(p) 
test assign_ent_sr=assign_man_sr 
estadd scalar p3=r(p) 
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_2

*** Column 3: Level of Profits in Past Month in All Businesses Conditional on Survival
xi: areg ctotalprof assign_ent_sr assign_man_sr assign_ent_lr assign_man_lr bl_aprofit_sr bl_aprofit_lr i.wave, a(tv_strata) cluster(id_ent) robust
sum ctotalprof if assign_group==3 & wave>=1 & wave<=4
estadd scalar mean1=r(mean)
estadd scalar sd1=r(sd)
sum ctotalprof if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_sr=assign_ent_lr
estadd scalar p1=r(p) 
test assign_man_sr=assign_man_lr 
estadd scalar p2=r(p) 
test assign_ent_sr=assign_man_sr 
estadd scalar p3=r(p) 
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_3

*** Column 4: Level of Sales in Past Month in Main Business
xi: areg mainsales assign_ent_sr assign_man_sr assign_ent_lr assign_man_lr bl_msales_sr bl_msales_lr i.wave, a(tv_strata) cluster(id_ent) robust
sum mainsales if assign_group==3 & wave>=1 & wave<=4
estadd scalar mean1=r(mean)
estadd scalar sd1=r(sd)
sum mainsales if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_sr=assign_ent_lr
estadd scalar p1=r(p) 
test assign_man_sr=assign_man_lr 
estadd scalar p2=r(p) 
test assign_ent_sr=assign_man_sr 
estadd scalar p3=r(p) 
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_4

*** Column 5: Level of Sales in Past Month in All Businesses
areg totalsales assign_ent_lr assign_man_lr bl_msales if wave==5, a(strata) robust
sum totalsales if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_5

*** Column 6: Level of Sales in Past Month in Main Business Conditional on Survival
xi: areg cmainsales assign_ent_sr assign_man_sr assign_ent_lr assign_man_lr bl_msales_sr bl_msales_lr i.wave, a(tv_strata) cluster(id_ent) robust
sum cmainsales if assign_group==3 & wave>=1 & wave<=4
estadd scalar mean1=r(mean)
estadd scalar sd1=r(sd)
sum cmainsales if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_sr=assign_ent_lr
estadd scalar p1=r(p) 
test assign_man_sr=assign_man_lr 
estadd scalar p2=r(p) 
test assign_ent_sr=assign_man_sr 
estadd scalar p3=r(p) 
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_6

*** Column 7: Profit and Sales Index 
xi: areg psindex assign_ent_sr assign_man_sr assign_ent_lr assign_man_lr bl_psindex_sr bl_psindex_lr i.wave, a(tv_strata) cluster(id_ent) robust
sum psindex if assign_group==3 & wave>=1 & wave<=4
estadd scalar mean1=r(mean)
estadd scalar sd1=r(sd)
sum psindex if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_sr=assign_ent_lr
estadd scalar p1=r(p) 
test assign_man_sr=assign_man_lr 
estadd scalar p2=r(p) 
test assign_ent_sr=assign_man_sr 
estadd scalar p3=r(p) 
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_7

*** Column 8: All Labor Income
xi: areg allincome assign_ent_sr assign_man_sr assign_ent_lr assign_man_lr bl_aprofit_sr bl_aprofit_lr i.wave, a(tv_strata) cluster(id_ent) robust
sum allincome if assign_group==3 & wave>=1 & wave<=4
estadd scalar mean1=r(mean)
estadd scalar sd1=r(sd)
sum allincome if assign_group==3 & wave==5
estadd scalar mean2=r(mean)
estadd scalar sd2=r(sd)
test assign_ent_sr=assign_ent_lr
estadd scalar p1=r(p) 
test assign_man_sr=assign_man_lr 
estadd scalar p2=r(p) 
test assign_ent_sr=assign_man_sr 
estadd scalar p3=r(p) 
test assign_ent_lr=assign_man_lr 
estadd scalar p4=r(p) 
eststo table1_8

#delimit ;
esttab table1_* using "$output/Table1Paper.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean1 sd1 mean2 sd2 p1 p2 p3 p4, fmt(%9.0f %9.0f %9.0f %9.0f %9.0f %9.3f %9.3f %9.3f %9.3f) labels("Sample Size" "Control Mean Short-run" "Control Mean Long-run" "p-value: PI SR=LR" "p-value: Trad SR=LR" "p-value: PI SR = Trad SR" "p-value: PI LR = Trad LR" )) 
	title("Table 1: Impact on Firm Profits and Sales") drop(_cons bl_mprofit* bl_aprofit* bl_msales* _Iwave* bl_psindex*);
#delimit cr

   ****************************************************************************************
   **** Table 2: Gender Heterogeneity in Personal Initiative Impacts and Mechanisms  ******
   **** and Table A7: Traditional Training Gender Heterogeneity                      ******
   ****************************************************************************************
 		use "$final/Togoanalysisdata.dta", clear  
eststo clear
keep id_ent assign_man assign_ent assign_group strata totalprof* bl_aprofit bl_no_workers PI_bl bl_business_practice ctotalprof* psindex* bl_psindex allincome* bl_female bl_no_workers memployees* w_employ2013 capital* baseK miss_baseK selfeff* bl_selfefficacy piindex* PIss_bl PI_bl_mi  bpindex*  Aind5 Aind4 bl_Aind
****** Reshape into a Panel *******
reshape long  totalprof ctotalprof psindex allincome memployees capital selfeff piindex bpindex  Aind, i(id_ent) j(wave)
gen assign_man_sr=0
replace assign_man_sr=assign_man if wave>=1 & wave<=4
gen assign_ent_sr=0
replace assign_ent_sr=assign_ent if wave>=1 & wave<=4
gen assign_man_lr=0
replace assign_man_lr=assign_man if wave==5
gen assign_ent_lr=0
replace assign_ent_lr=assign_ent if wave==5

foreach var in assign_man_sr assign_ent_sr assign_man_lr assign_ent_lr {
	cap drop `var'_male
	gen `var'_male=`var'*(1-bl_female)
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}

for num 1/5: gen waveX=wave==X
for num 1/5: gen waveX_female=waveX*bl_female
foreach var in bl_aprofit  bl_psindex bl_business_practice {
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}
*** Saturated model so that coefficients on lr are the same as when sr no included
gen bl_aprofit_sr=0
replace bl_aprofit_sr=bl_aprofit if wave>=1 & wave<=4
gen bl_aprofit_lr=0
replace bl_aprofit_lr=bl_aprofit if wave==5
gen bl_aprofit_sr_female=bl_aprofit_sr*bl_female 
gen bl_aprofit_lr_female=bl_aprofit_lr*bl_female 
gen bl_psindex_sr=0
replace bl_psindex_sr=bl_psindex if wave>=1 & wave<=4
gen bl_psindex_lr=0
replace bl_psindex_lr=bl_psindex if wave==5
gen bl_psindex_sr_female=bl_psindex_sr*bl_female 
gen bl_psindex_lr_female=bl_psindex_lr*bl_female
gen w_employ2013_sr=0
replace w_employ2013_sr=w_employ2013 if wave>=1 & wave<=4
gen w_employ2013_lr=0
replace w_employ2013_lr=w_employ2013 if wave==5
gen w_employ2013_sr_female=w_employ2013_sr*bl_female
gen w_employ2013_lr_female=w_employ2013_lr*bl_female
foreach var of varlist baseK miss_baseK bl_selfefficacy bl_Aind  {
gen `var'_sr=0
gen `var'_lr=0
replace `var'_sr=`var' if wave==4
replace `var'_lr=`var' if wave==5
gen `var'_sr_female=`var'_sr*bl_female 
gen `var'_lr_female=`var'_lr*bl_female		
}
foreach var of varlist PIss_bl PI_bl_mi bl_business_practice  {
gen `var'_sr=0
gen `var'_lr=0
replace `var'_sr=`var' if wave>=1 & wave<=4
replace `var'_lr=`var' if wave==5
gen `var'_sr_female=`var'_sr*bl_female 
gen `var'_lr_female=`var'_lr*bl_female		
}
*** Allow strata coefficients to also differ in SR and LR
gen tv_strata=0
replace tv_strata=strata if wave>=1 & wave<=4
replace tv_strata=1000*strata if wave==5
distinct tv_strata

*** Column 1: Total Profits
areg totalprof assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
bl_aprofit_sr bl_aprofit_lr bl_aprofit_sr_female bl_aprofit_lr_female wave1-wave5 wave1_female-wave5_female, a(tv_strata) cluster(id_ent) robust

*sample means
sum totalprof if assign_group==3 & wave>=1 & wave<=4 & bl_female==0
estadd scalar mean1=r(mean)
sum totalprof if assign_group==3 & wave>=1 & wave<=4 & bl_female==1
estadd scalar mean2=r(mean)
sum totalprof if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum totalprof if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_1

*** Column 2: Total Profits Conditional on Survival
areg ctotalprof assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
bl_aprofit_sr bl_aprofit_lr bl_aprofit_sr_female bl_aprofit_lr_female wave1-wave5 wave1_female-wave5_female, a(tv_strata) cluster(id_ent) robust

*sample means
sum ctotalprof if assign_group==3 & wave>=1 & wave<=4 & bl_female==0
estadd scalar mean1=r(mean)
sum ctotalprof if assign_group==3 & wave>=1 & wave<=4 & bl_female==1
estadd scalar mean2=r(mean)
sum ctotalprof if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum ctotalprof if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_2

*** Column 3: Profit and Sales Index 
areg psindex assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
bl_psindex_sr bl_psindex_lr bl_psindex_sr_female bl_psindex_lr_female wave1-wave5 wave1_female-wave5_female, a(tv_strata) cluster(id_ent) robust
*sample means
sum psindex if assign_group==3 & wave>=1 & wave<=4 & bl_female==0
estadd scalar mean1=r(mean)
sum psindex if assign_group==3 & wave>=1 & wave<=4 & bl_female==1
estadd scalar mean2=r(mean)
sum psindex if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum psindex if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_3

*** Column 4: All Labor Income 
areg allincome assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
bl_aprofit_sr bl_aprofit_lr bl_aprofit_sr_female bl_aprofit_lr_female wave1-wave5 wave1_female-wave5_female, a(tv_strata) cluster(id_ent) robust
*sample means
sum allincome if assign_group==3 & wave>=1 & wave<=4 & bl_female==0
estadd scalar mean1=r(mean)
sum allincome if assign_group==3 & wave>=1 & wave<=4 & bl_female==1
estadd scalar mean2=r(mean)
sum allincome if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum allincome if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_4

*** Column 5: Employees in Main Firm
areg memployees assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
w_employ2013_sr w_employ2013_lr w_employ2013_sr_female w_employ2013_lr_female wave1-wave5 wave1_female-wave5_female if (wave==4|wave==5), a(tv_strata) cluster(id_ent) robust
*sample means
sum memployees if assign_group==3 & wave>=1 & wave<=4 & bl_female==0
estadd scalar mean1=r(mean)
sum memployees if assign_group==3 & wave>=1 & wave<=4 & bl_female==1
estadd scalar mean2=r(mean)
sum memployees if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum memployees if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_5

*** Column 6: Capital Stock (waves 4 and 5 only to get end stock)
areg capital assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
baseK_sr baseK_sr_female baseK_lr baseK_lr_female miss_baseK_sr miss_baseK_lr miss_baseK_sr_female miss_baseK_lr_female ///
wave4-wave5 wave4_female-wave5_female if (wave==4|wave==5), a(tv_strata) cluster(id_ent) robust
*sample means
sum capital if assign_group==3 & wave==4 & bl_female==0
estadd scalar mean1=r(mean)
sum capital if assign_group==3 & wave==4 & bl_female==1
estadd scalar mean2=r(mean)
sum capital if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum capital if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_6

**** Column 7: Entrepreneurial Self-efficacy
areg selfeff assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
bl_selfefficacy_sr bl_selfefficacy_sr_female bl_selfefficacy_lr bl_selfefficacy_lr_female ///
wave4-wave5 wave4_female-wave5_female if (wave==4|wave==5), a(tv_strata) cluster(id_ent) robust
*sample means
sum selfeff if assign_group==3 & wave==4 & bl_female==0
estadd scalar mean1=r(mean)
sum selfeff if assign_group==3 & wave==4 & bl_female==1
estadd scalar mean2=r(mean)
sum selfeff if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum selfeff if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_7

**** Column 8: PI index 
areg piindex assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
PIss_bl_sr PI_bl_mi_sr PIss_bl_lr PI_bl_mi_lr PIss_bl_sr_female PI_bl_mi_sr_female PIss_bl_lr_female PI_bl_mi_lr_female ///
wave1-wave5 wave1_female-wave5_female, a(tv_strata) cluster(id_ent) robust
*sample means
sum piindex if assign_group==3 & wave>=1 & wave<=4 & bl_female==0
estadd scalar mean1=r(mean)
sum piindex if assign_group==3 & wave>=1 & wave<=4 & bl_female==1
estadd scalar mean2=r(mean)
sum piindex if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum piindex if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_8


**** Column 9: BP index
areg bpindex assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
bl_business_practice_sr bl_business_practice_lr bl_business_practice_sr_female  bl_business_practice_lr_female  ///
wave1-wave5 wave1_female-wave5_female, a(tv_strata) cluster(id_ent) robust
*sample means
sum bpindex if assign_group==3 & wave>=1 & wave<=4 & bl_female==0
estadd scalar mean1=r(mean)
sum bpindex if assign_group==3 & wave>=1 & wave<=4 & bl_female==1
estadd scalar mean2=r(mean)
sum bpindex if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum bpindex if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_9

**** Column 10: A index
areg Aind assign_ent_sr_male assign_ent_sr_female assign_ent_lr_male assign_ent_lr_female ///
assign_man_sr_male assign_man_sr_female assign_man_lr_male assign_man_lr_female ///
bl_Aind_sr bl_Aind_sr_female bl_Aind_lr bl_Aind_lr_female ///
wave4-wave5 wave4_female-wave5_female if (wave==4|wave==5), a(tv_strata) cluster(id_ent) robust
*sample means
sum Aind  if assign_group==3 & wave==4 & bl_female==0
estadd scalar mean1=r(mean)
sum Aind  if assign_group==3 & wave==4 & bl_female==1
estadd scalar mean2=r(mean)
sum Aind  if assign_group==3 & wave==5 & bl_female==0
estadd scalar mean3=r(mean)
sum Aind  if assign_group==3 & wave==5 & bl_female==1
estadd scalar mean4=r(mean)
* Test of gender equality
test assign_ent_sr_male=assign_ent_sr_female
estadd scalar p1=r(p) 
test assign_ent_lr_male=assign_ent_lr_female
estadd scalar p2=r(p) 
test assign_man_sr_male=assign_man_sr_female
estadd scalar p3=r(p) 
test assign_man_lr_male=assign_man_lr_female 
estadd scalar p4=r(p) 
* Test of Convergence/Divergence
test assign_ent_sr_male=assign_ent_lr_male 
estadd scalar p5=r(p)
test assign_ent_sr_female=assign_ent_lr_female 
estadd scalar p6=r(p)
eststo table2_10

*** Table 2 has the PI results
#delimit ;
esttab table2_* using "$output/Table2Paper.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean1 mean2 mean3 mean4 p1 p2 p5 p6, fmt(%9.0f %9.2f %9.2f %9.2f %9.2f %9.3f %9.3f %9.3f %9.3f) labels("Sample Size" "Control Mean Men SR" "Control Mean Women SR" "Control Mean Men LR" "Control Mean Women LR" "p-value: PI Men=Women SR" "p-value: PI Men=Women LR" "p-value: PI SR=LR Men" "p-value: PI SR=LR Women" )) 
	title("Table 2: Gender Heterogeneity in Personal Initiative Impact and Mechanisms") drop(_cons  bl* wave* miss_baseK* baseK* w_employ* bl_selfefficacy* PIss* PI_bl* assign_man*);
#delimit cr
*** Table A7: has the Traditional Training results
#delimit ;
esttab table2_* using "$output/TableA7.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean1 mean2 mean3 mean4  p3 p4, fmt(%9.0f %9.2f %9.2f %9.2f %9.2f %9.3f %9.3f) labels("Sample Size" "Control Mean Men SR" "Control Mean Women SR" "Control Mean Men LR" "Control Mean Women LR"  "p-value: Trad Men=Women SR" "p-value: Trad Men=Women LR")) 
	title("Table A7: Gender Heterogeneity in Traditional Training Impact and Mechanisms") drop(_cons  bl* wave* miss_baseK* baseK* w_employ* bl_selfefficacy* PIss* PI_bl* assign_ent*);
#delimit cr



******************************************************************************
**** Table 3: Gender Heterogeneity in Long-run impacts in Subsamples    ******
******************************************************************************
 		use "$final/Togoanalysisdata.dta", clear  
foreach var in assign_man assign_ent {
	cap drop `var'_male
	gen `var'_male=`var'*(1-bl_female)
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}
gen bl_aprofit_female=bl_aprofit*bl_female


*** note: don't include strata fixed effects when splitting into subsamples
*** since some strata won't have both T and C in the same subsample and so would get dropped
eststo clear
*** Column 1: Low profit firms
reg totalprof5 assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_aprofit bl_aprofit_female if lowprofit==1, robust 
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  totalprof5 if bl_female==0 & lowprofit==1
estadd scalar mean1=r(mean)
sum  totalprof5 if bl_female==1 & lowprofit==1
estadd scalar mean2=r(mean)
eststo table3_1

*** Column 2: high profit firms
reg totalprof5 assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_aprofit bl_aprofit_female if lowprofit==0, robust 
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  totalprof5 if bl_female==0 & lowprofit==0
estadd scalar mean1=r(mean)
sum  totalprof5 if bl_female==1 & lowprofit==0
estadd scalar mean2=r(mean)
eststo table3_2

*** Column 3: commerce firms (77% women in commerce, 22% men)
reg totalprof5 assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_aprofit bl_aprofit_female if bl_commerce==1, robust 
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  totalprof5 if bl_female==0 & bl_commerce==1
estadd scalar mean1=r(mean)
sum  totalprof5 if bl_female==1 & bl_commerce==1
estadd scalar mean2=r(mean)
eststo table3_3

*** Column 4: not in commerce (23% women, 78% men)
reg totalprof5 assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_aprofit bl_aprofit_female if bl_commerce~=1, robust
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  totalprof5 if bl_female==0 & bl_commerce~=1
estadd scalar mean1=r(mean)
sum  totalprof5 if bl_female==1 & bl_commerce~=1
estadd scalar mean2=r(mean)
eststo table3_4

*** Column 5: Impact on other household member running a business
areg  otherhhbus assign_ent_male assign_ent_female assign_man_male assign_man_female bl_female, r a(strata)
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  otherhhbus if bl_female==0
estadd scalar mean1=r(mean)
sum  otherhhbus if bl_female==1 
estadd scalar mean2=r(mean)
eststo table3_5

*** Since no significant impact on having another member run a business, heterogeneity by this
*** Column 6: No one else in household runs a business
reg totalprof5 assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_aprofit bl_aprofit_female if otherhhbus==0, robust 
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  totalprof5 if bl_female==0 & otherhhbus==0
estadd scalar mean1=r(mean)
sum  totalprof5 if bl_female==1 & otherhhbus==0
estadd scalar mean2=r(mean)
eststo table3_6

*** Column 7: Someone else in household runs a business
reg totalprof5 assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_aprofit bl_aprofit_female if otherhhbus==1, robust 
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  totalprof5 if bl_female==0 & otherhhbus==1
estadd scalar mean1=r(mean)
sum  totalprof5 if bl_female==1 & otherhhbus==1
estadd scalar mean2=r(mean)
eststo table3_7


#delimit ;
esttab table3_* using "$output/Table3Paper.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean1 mean2 p1 p2, fmt(%9.0f %9.2f %9.2f %9.3f %9.3f) labels("Sample Size" "Control Mean Men" "Control Mean Women" "p-value: PI Men=Women" "p-value: Trad Men=Women" )) 
	title("Table 3: Gender Heterogeneity in Long-Run Impacts in Subsamples") drop(_cons  bl*);
#delimit cr

	
	********************************************************************************
	**** Appendix Tables and Figures                                         *******
	********************************************************************************
	
	*********************************************************************
	****** Figure A1: Capital Stock Trajectory and Quantile Effects *****
	*********************************************************************
		use "$final/Togoanalysisdata.dta", clear
	
	***Panel A: Capital Stock by Gender
*** Males
preserve 
keep if bl_female==0
keep id_ent kstock2013 kstock2016 kstock2021 assign_group
reshape long kstock, i(id_ent assign_group) j(year)
label var kstock "Capital Stock"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar kstock, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.0f) graphopts(title("Men") xtitle("") ytitle("Capital Stock") graphregion(color(white)) ylabel(0(1500)9000) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(2000)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig_A1m.gph", replace	
restore

*** Females
preserve 
keep if bl_female==1
keep id_ent kstock2013 kstock2016 kstock2021 assign_group
reshape long kstock, i(id_ent assign_group) j(year)
label var kstock "Capital Stock"
label define wavelabels 2013 "2013 (Baseline)" 2016 "2016 (2-Year)" 2021 "2021 (7-Year)"
label values year wavelabels
gen treat=assign_group
replace treat=1 if assign_group==2
replace treat=2 if assign_group==1
label define tgroup 1 "Personal Initiative" 2 "Traditional Training"  3 "Control"
label values treat tgroup
cibar kstock, over1(treat) over2(year) barcol(maroon navy ltblue) barlabel(on) blf(%9.0f) graphopts(title("Women") xtitle("") ytitle("Capital Stock") graphregion(color(white)) ylabel(0(1500)9000) legend(pos(6) col(3) order(1 "Personal Initiative" 2 "Traditional Training" 3 "Control"))) blsize(small) blgap(1500)
gr_edit xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
	graph save 	"$output/figures/Fig_A1f.gph", replace	
restore

grc1leg "$output/figures/Fig_A1m.gph" "$output/figures/Fig_A1f.gph", col(2) graphregion(color(white)) legendfrom("$output/figures/Fig_A1m.gph") ///
title ("A: Mean Capital Stock by Gender and Time Period")
graph save "$output/figures/FigA1panelA.gph", replace

   **** Panel B: Quantile Treatment Effects for Capital Stock
  use "$final/Togoanalysisdata.dta", clear
 **** Short-Run (2016)
clear matrix
preserve
eststo clear
foreach var in assign_man assign_ent {
	cap drop `var'_male
	gen `var'_male=`var'*(1-bl_female)
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}
cap drop win_bl_k_stock_female
gen win_bl_k_stock_female=win_bl_k_stock*bl_female 
forval i=.05(.05) 1 {
	di `i'
		
    quietly qreg2 kstock2016 assign_man_male assign_man_female assign_ent_male assign_ent_female win_bl_k_stock win_bl_k_stock_female bl_female, q(`i')
		scalar betalrm = _b[assign_ent_male]
		scalar betalrf = _b[assign_ent_female]
		quietly test assign_ent_male==assign_ent_female 
		scalar pvallr = r(p)
		matrix pool_qreg = [nullmat(pool_qreg) \ `i',  betalrm, betalrf, pvallr]
	}

clear
svmat pool_qreg
	ren pool_qreg1 qtile
	ren pool_qreg2 lrm
	ren pool_qreg3 lrf
	ren pool_qreg4 pvallr
	
gen y0=0
gen Percentile=qtile*100
sort Percentile
replace y0=. if Percentile<5 | Percentile>95
gen z0=0.10
replace z0=. if Percentile<5 | Percentile>95

format  lrm lrf %6.0f
format pvallr %9.3f 

twoway (line lrm Percentile if Percentile>=5 & Percentile<=95, lwidth(thick) lcolor(black) lpattern(line))   ///
	   (line lrf Percentile if Percentile>=5 & Percentile<=95, lwidth(thin) lcolor(black) lpattern(dash) ) ///  
	   (line y0 Percentile if Percentile>=10 & Percentile<=95, lcolor(black)), ///
	    xlabel( 5 10 20 30 40 50 60 70 80 90 95) ylabel(0 2000 4000) ///
		title("Short-run Capital") ytitle("Impact on Capital Stock") xtitle("Quantile") ///
		scheme(s1manual) legend(order(1 "Men" 2 "Women")) legend(rows(1))	
graph save "$output/figures/FigureA1_SR.gph", replace
restore

**** Long-Run
clear matrix
preserve

eststo clear
foreach var in assign_man assign_ent {
	cap drop `var'_male
	gen `var'_male=`var'*(1-bl_female)
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}
cap drop win_bl_k_stock_female
gen win_bl_k_stock_female=win_bl_k_stock*bl_female 

forval i=.05(.05) 1 {
	di `i'
		
    quietly qreg2 totasset2_w assign_man_male assign_man_female assign_ent_male assign_ent_female win_bl_k_stock win_bl_k_stock_female bl_female, q(`i')
		scalar betalrm = _b[assign_ent_male]
		scalar betalrf = _b[assign_ent_female]
		quietly test assign_ent_male==assign_ent_female 
		scalar pvallr = r(p)
		matrix pool_qreg = [nullmat(pool_qreg) \ `i',  betalrm, betalrf, pvallr]
	}

clear
svmat pool_qreg
	ren pool_qreg1 qtile
	ren pool_qreg2 lrm
	ren pool_qreg3 lrf
	ren pool_qreg4 pvallr
	
gen y0=0
gen Percentile=qtile*100
sort Percentile
replace y0=. if Percentile<5 | Percentile>95
gen z0=0.10
replace z0=. if Percentile<5 | Percentile>95

format  lrm lrf %6.0f
format pvallr %9.3f 

twoway (line lrm Percentile if Percentile>=5 & Percentile<=95, lwidth(thick) lcolor(black) lpattern(line))   ///
	   (line lrf Percentile if Percentile>=5 & Percentile<=95, lwidth(thin) lcolor(black) lpattern(dash) ) ///  
	   (line y0 Percentile if Percentile>=10 & Percentile<=95, lcolor(black)), ///
	    xlabel( 5 10 20 30 40 50 60 70 80 90 95)  ///
		title("Long-run Capital") ytitle("Impact on Capital Stock") xtitle("Quantile") ///
		scheme(s1manual) legend(order(1 "Men" 2 "Women")) legend(rows(1))	
graph save "$output/figures/FigureA1_LR.gph", replace


restore

grc1leg "$output/figures/FigureA1_SR.gph" "$output/figures/FigureA1_LR.gph", col(2) graphregion(color(white)) legendfrom("$output/figures/FigureA1_SR.gph") title("B: PI Quantile Treatment Effects on Capital Stock")
graph save "$output/figures/FigA1panelB.gph", replace

******* Making Figure A1 *********************************
graph combine "$output/figures/FigA1panelA.gph" "$output/figures/FigA1panelB.gph", col(1) scheme(s1manual)
graph save "$output/figures/FigureA1Paper.gph", replace
graph export "$output/figures/FigureA1Paper.pdf", replace
graph export "$output/figures/FigureA1Paper.png", replace

	
	
	*********************************************************
	****** Table A1: Revised Response Rate Table ************
	*********************************************************
	use "$final/Togoanalysisdata.dta", clear
	local i=1
	mat y= J(8,8,.)
	foreach var of varlist interviewed_fu1 interviewed_fu2 interviewed_fu3 interviewed_fu4 response_rate_ip response_rate_ps response_rate_at_ip_ps response_rate_comp {
		* Mean response rate by treatment status for response type
		sum `var' if assign_ent==1
		mat y[1, `i']= r(mean)
		sum `var' if assign_man==1
		mat y[2, `i']= r(mean)
		sum `var' if assign_control==1
		mat y[3, `i']= r(mean)
		* Total sample size with data
		count if `var'==1
		mat y[4, `i']= r(N)
		* Overall response rate
		sum `var'
		mat y[5,`i']=r(mean)
		* Treatment regression p-values
		areg `var' assign_ent assign_man, r a(bl_stratafinal)
		test assign_ent==0
		mat y[6, `i']= r(p)
		test assign_man==0
		mat y[7, `i']= r(p)		
		test assign_ent==assign_man
		mat y[8, `i']= r(p)
	local i = `i'+1
	}
mat colnames y = " Round 1" "Round 2" "Round 3" "Round 4" "In-person survey" "Phone survey" "Either" "Know status"
mat rownames y = "PI response rate" "Traditional response rate" "Control response rate" "Total observations" "Overall response rate" "p-value: PI=0" "p-value: Trad=0" "p-value: PI=Trad"

mat2txt, matrix(y) saving("$output/TableA1.xls") format(%9.3f) replace


***********************************************************************
**** Table A2a: Balance Table for non-attritors                   *****
***********************************************************************
use "$final/Togoanalysisdata.dta", clear
local base_var us_win_bl_profits_lm bl_commerce bl_production bl_female bl_age bl_years_schooling bl_firm_age us_win_bl_sales_lm us_win_bl_sales_lw us_win_bl_profits_lw us_win_bl_k_stock bl_no_workers PI_bl bl_business_practice  

mat y=J(15,6,.)
local i=1
foreach var of local base_var {
* Overall mean and SD
sum `var' if response_rate_at_ip_ps 
mat y[`i',1]=r(mean)
mat y[`i',2]=r(sd)
* Means by Treatment Status
* Control
sum `var' if response_rate_at_ip_ps & assign_control==1
mat y[`i',3]=r(mean)
* PI group
sum `var' if response_rate_at_ip_ps & assign_ent==1
mat y[`i',4]=r(mean)
* Traditional group
sum `var' if response_rate_at_ip_ps & assign_man==1
mat y[`i',5]=r(mean)
* Test of equality of means, after controlling for strata dummies
areg `var' assign_ent assign_man if response_rate_at_ip_ps==1, r a(bl_stratafinal)
test assign_ent==assign_man==0
mat y[`i',6]=r(p)	
local i=`i'+1
}
count if response_rate_at_ip_ps ==1
mat y[15,1]=r(N)
count if response_rate_at_ip_ps  & assign_control==1
mat y[15,3]=r(N)
count if response_rate_at_ip_ps  & assign_ent==1
mat y[15,4]=r(N)
count if response_rate_at_ip_ps  & assign_man==1
mat y[15,5]=r(N)

mat colnames y = "Overall Mean" "Overall SD" "Control Mean" "PI Mean" "Trad Mean" "p-value equality" 
mat rownames y = "Monthly profits" "Commerce sector" "Production sector" "Female" "Age of Owner" "Years schooling" "Firm age" ///
"Monthly sales" "Weekly sales" "Weekly profits" "Capital stock" "Number of Workers" "Personal initiative index" "Business practices"  "Sample Size"
mat2txt, matrix(y) saving("$output/TableA2a.xls") format(%9.2f %9.2f %9.2f %9.2f %9.2f %9.3f ) replace



*******************************************************************
**** Table A2b: Balance Table for attritors                   *****
*******************************************************************
local base_var us_win_bl_profits_lm bl_commerce bl_production bl_female bl_age bl_years_schooling bl_firm_age us_win_bl_sales_lm us_win_bl_sales_lw us_win_bl_profits_lw us_win_bl_k_stock bl_no_workers PI_bl bl_business_practice  

mat y=J(15,6,.)
local i=1
foreach var of local base_var {
* Overall mean and SD
sum `var' if response_rate_at_ip_ps==0
mat y[`i',1]=r(mean)
mat y[`i',2]=r(sd)
* Means by Treatment Status
* Control
sum `var' if response_rate_at_ip_ps==0 & assign_control==1
mat y[`i',3]=r(mean)
* PI group
sum `var' if response_rate_at_ip_ps==0 & assign_ent==1
mat y[`i',4]=r(mean)
* Traditional group
sum `var' if response_rate_at_ip_ps==0 & assign_man==1
mat y[`i',5]=r(mean)
* Test of equality of means, after controlling for strata dummies
areg `var' assign_ent assign_man if response_rate_at_ip_ps==0, r a(bl_stratafinal)
test assign_ent==assign_man==0
mat y[`i',6]=r(p)	
local i=`i'+1
}
count if response_rate_at_ip_ps ==0
mat y[15,1]=r(N)
count if response_rate_at_ip_ps==0  & assign_control==1
mat y[15,3]=r(N)
count if response_rate_at_ip_ps==0  & assign_ent==1
mat y[15,4]=r(N)
count if response_rate_at_ip_ps==0  & assign_man==1
mat y[15,5]=r(N)

mat colnames y = "Overall Mean" "Overall SD" "Control Mean" "PI Mean" "Trad Mean" "p-value equality" 
mat rownames y = "Monthly profits" "Commerce sector" "Production sector" "Female" "Age of Owner" "Years schooling" "Firm age" ///
"Monthly sales" "Weekly sales" "Weekly profits" "Capital stock" "Number of Workers" "Personal initiative index" "Business practices"  "Sample Size"
mat2txt, matrix(y) saving("$output/TableA2b.xls") format(%9.2f %9.2f %9.2f %9.2f %9.2f %9.3f ) replace

******************************************************************************
**** Table A3: Dynamics of who are the marginal responders? ******************
******************************************************************************
use "$final/Togoanalysisdata.dta", clear

* Look at characteristics of baseline variables, round 4 response status, round 4 operating status, and current operating status and LR profits	
local base_var interviewed_fu4 open_company_fu4 fu4_win_profits_med PI_fu4 fu4_business_practice selfemployed allbusi_totprof_lastmonth_as_wu

mat y=J(8,12,.)
local i=1
foreach var of local base_var {
* Full sample
sum `var' if respgroup==1
mat y[`i',1]=r(mean)
sum `var' if respgroup==2
mat y[`i',2]=r(mean)	
sum `var' if respgroup==3
mat y[`i',3]=r(mean)	
reg `var' rgroup2 rgroup3, r
test rgroup2==rgroup3==0
mat y[`i',4]=r(p)
* Control group
sum `var' if respgroup==1 & assign_control==1
mat y[`i',5]=r(mean)
sum `var' if respgroup==2 & assign_control==1
mat y[`i',6]=r(mean)	
sum `var' if respgroup==3 & assign_control==1
mat y[`i',7]=r(mean)	
reg `var' rgroup2 rgroup3 if assign_control==1, r
test rgroup2==rgroup3==0
mat y[`i',8]=r(p)
* PI group
sum `var' if respgroup==1 & assign_ent==1
mat y[`i',9]=r(mean)
sum `var' if respgroup==2 & assign_ent==1
mat y[`i',10]=r(mean)	
sum `var' if respgroup==3 & assign_ent==1
mat y[`i',11]=r(mean)	
reg `var' rgroup2 rgroup3 if assign_ent==1, r
test rgroup2==rgroup3==0
mat y[`i',12]=r(p)

	
local i=`i'+1
}
count if respgroup==1
mat y[8,1]=r(N)
count if respgroup==2
mat y[8,2]=r(N)
count if respgroup==3
mat y[8,3]=r(N)

count if respgroup==1 & assign_control==1
mat y[8,5]=r(N)
count if respgroup==2 & assign_control==1
mat y[8,6]=r(N)
count if respgroup==3 & assign_control==1
mat y[8,7]=r(N)

count if respgroup==1 & assign_ent==1
mat y[8,9]=r(N)
count if respgroup==2 & assign_ent==1
mat y[8,10]=r(N)
count if respgroup==3 & assign_ent==1
mat y[8,11]=r(N)

mat colnames y = "Both" "Only one" "Neither" "p-value" "Both" "Only one" "Neither" "p-value" "Both" "Only one" "Neither" "p-value"
mat rownames y = "Answered Round 4" ///
"Open in Round 4" "Above Median profits round 4" "PI in round 4" "Business Practices in round 4" "Self-employed after 7 years" "Profits LR"  "Sample Size"
mat2txt, matrix(y) saving("$output/TableA3.xls") format(%9.2f %9.2f %9.2f %9.3f %9.2f %9.2f %9.2f %9.3f  %9.2f %9.2f %9.2f %9.3f) replace	

*********************************************************************************
**** Table A4: Robustness of Long-term impact on being self-employed         ****
*********************************************************************************
use "$final/Togoanalysisdata.dta", clear

eststo clear
local i=1
foreach var of varlist selfemployed selfemployed100 selfemployed92 selfemployed50 selfemployed0  {
	areg `var' assign_ent assign_man, r a(bl_stratafinal)
	test assign_ent==assign_man
	estadd scalar pval2=r(p)
	sum `var' if e(sample)==1 & assign_control==1
	estadd scalar mean2=r(mean)
	eststo tableA4_`i'
	local i=`i'+1
}
	
#delimit ;
esttab tableA4_*  using "$output/tableA4.csv", replace depvar legend label nonumbers nogaps
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) drop(_cons)
	stats(N mean2 pval2, fmt(%9.0g %9.3f  %9.3f) labels("Sample Size" "Control Mean" "p-value: PI=Trad" )) 
	title("Table A4: Robustness of Impact on Self-Employment");	
#delimit cr


*********************************************************************************
**** Table A5: Robustness of Long-term profit impact to attrition            ****
*********************************************************************************
use "$final/Togoanalysisdata.dta", clear


eststo clear
*** Base specification
areg totalprof5 assign_ent assign_man  bl_aprofit, a(strata) robust
sum totalprof5 if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_1
*** PDS Lasso controls - note does not select any controls for treatment, selects sales, capital, weekly profits as additional controls for Y
local lassocontrols bl_age bl_years_schooling bl_firm_age win_bl_sales_lm win_bl_sales_lw win_bl_profits_lw win_bl_k_stock PI_bl bl_business_practice 
xi: pdslasso totalprof5 assign_ent assign_man  (bl_aprofit `lassocontrols' i.bl_stratafinal), partial(bl_aprofit i.bl_stratafinal)
sum totalprof5 if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_2
*** Survey month fixed effects
xi: areg totalprof5 assign_ent assign_man  bl_aprofit i.month_as, a(strata) robust
sum totalprof5 if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_3
*** Lower Lee bound
areg lblower assign_ent assign_man  bl_aprofit, a(strata) robust
sum lblower if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_4
*** Upper Lee bound 
areg lbupper assign_ent assign_man  bl_aprofit, a(strata) robust
sum lbupper if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_5
*** Assume all missing earn the best they ever have in prior rounds
areg robustprof1 assign_ent assign_man  bl_aprofit, a(strata) robust
sum robustprof1 if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_6
**** Assume all missing earn average of those who answer once
areg robustprof2 assign_ent assign_man  bl_aprofit, a(strata) robust
sum robustprof2 if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_7
**** Assume all missing earn zero
areg robustprof3 assign_ent assign_man  bl_aprofit, a(strata) robust
sum robustprof3 if assign_control==1 & e(sample)
estadd scalar mean=r(mean)
eststo tablea5_8

#delimit ;
esttab tablea5_* using "$output/TableA5.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean, fmt(%9.0f) labels("Sample Size" "Assumed Control Mean")) 
	title("Table A5: Robustness of Profits Impact to Attrition Assumptions") drop(_cons bl_aprofit _I* win_*);
#delimit cr

*********************************************************************************
**** Table A6: Robustness to other measures of profits and sales             ****
*********************************************************************************
use "$final/Togoanalysisdata.dta", clear

*** Panel A: Other measures of profits 
eststo clear
local i=1
foreach var in logprof bestmonthprof worstmonthprof profb2019 profw2019 otherprofindex {
areg `var' assign_ent assign_man bl_`var', a(strata) robust
sum `var' if assign_group==3 
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
test assign_ent=assign_man
estadd scalar p1=r(p) 
eststo tablea6a_`i'
local i=`i'+1
}
*** Panel B: Other measures of sales
local i=1
foreach var in logsales bestmonthsales worstmonthsales salesb2019 salesw2019 othersalesindex {
areg `var' assign_ent assign_man bl_`var', a(strata) robust
sum `var' if assign_group==3 
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
test assign_ent=assign_man
estadd scalar p1=r(p) 
eststo tablea6b_`i'
local i=`i'+1
}


#delimit ;
esttab tablea6a_* using "$output/TableA6.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean sd p1, fmt(%9.0f %9.1f %9.1f %9.3f) labels("Sample Size" "Control Mean" "Control SD" "p-value: PI = Trad" )) 
	posthead("Panel A: Profits")
	title("Table A6: Impact on Other Measures of Profits and Sales") drop(_cons bl_*);
esttab tablea6b_* using "$output/TableA6.csv", append depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean sd p1, fmt(%9.0f %9.1f %9.1f %9.3f) labels("Sample Size" "Control Mean" "Control SD" "p-value: PI = Trad" )) 
	posthead("Panel B: Sales")
	 drop(_cons bl_*);
#delimit cr


*******************************************************************************
*** Table A7: See above: created with Table 2                         *********
*******************************************************************************

*******************************************************************************
*** Table A8: Gender Heterogeneity in Other Outcomes and Mechanisms *********
*****************************************************************************
 		use "$final/Togoanalysisdata.dta", clear  
foreach var in assign_man assign_ent {
	cap drop `var'_male
	gen `var'_male=`var'*(1-bl_female)
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}
foreach var in bl_aprofit bl_no_workers bl_new_products {
	gen `var'_female=`var'*bl_female
}

eststo clear
*** Column 1: Survival 
areg selfemployed assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female, robust a(strata)
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum selfemployed if bl_female==0
estadd scalar mean1=r(mean)
sum selfemployed if bl_female==1
estadd scalar mean2=r(mean)
eststo tableA8_1

*** Column 2: All Employees
areg allemployees_w assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_no_workers bl_no_workers_female, robust a(strata)
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum allemployees_w if bl_female==0
estadd scalar mean1=r(mean)
sum allemployees_w if bl_female==1
estadd scalar mean2=r(mean)
eststo tableA8_2

*** Column 3: Paid Employees in all Firms
areg allpaidemployees_w assign_ent_male assign_ent_female assign_man_male assign_man_female ///
bl_female bl_no_workers bl_no_workers_female, robust a(strata)
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum allpaidemployees_w if bl_female==0
estadd scalar mean1=r(mean)
sum allpaidemployees_w if bl_female==1
estadd scalar mean2=r(mean)
eststo tableA8_3

*** Columm 4: Innovation Index
areg  innovateindex assign_ent_male assign_ent_female assign_man_male assign_man_female bl_female bl_new_products bl_new_products_female, r a(strata)
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  innovateindex if bl_female==0 
estadd scalar mean1=r(mean)
sum  innovateindex if bl_female==1 
estadd scalar mean2=r(mean)
eststo tableA8_4

*** Column 5: Digital Index
areg  digitalindex assign_ent_male assign_ent_female assign_man_male assign_man_female bl_female, r a(strata)
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  digitalindex if bl_female==0 
estadd scalar mean1=r(mean)
sum  digitalindex if bl_female==1 
estadd scalar mean2=r(mean)
eststo tableA8_5

**** Column 6: Maximum amount can borrow 
areg  maxloan_w assign_ent_male assign_ent_female assign_man_male assign_man_female bl_female, r a(strata)
test assign_ent_male=assign_ent_female 
estadd scalar p1=r(p)
test assign_man_male=assign_man_female 
estadd scalar p2=r(p)
sum  maxloan_w  if bl_female==0 
estadd scalar mean1=r(mean)
sum maxloan_w  if bl_female==1 
estadd scalar mean2=r(mean)
eststo tableA8_6

#delimit ;
esttab tableA8_* using "$output/TableA8.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean1 mean2 p1 p2, fmt(%9.0f %9.2f %9.2f %9.3f %9.3f) labels("Sample Size" "Control Mean Men" "Control Mean Women" "p-value: PI Men=Women" "p-value: Trad Men=Women" )) 
	title("Table A8: Additional Gender Heterogeneity in Impact and Mechanisms") drop(_cons  bl_*);
#delimit cr


*****************************************************************************
*** Table A9: Impacts on different components of capital stock  *************
*****************************************************************************
 		use "$final/Togoanalysisdata.dta", clear  
foreach var in assign_man assign_ent {
	cap drop `var'_male
	gen `var'_male=`var'*(1-bl_female)
	cap drop `var'_female
	gen `var'_female=`var'*bl_female
}
cap drop bl_kstock_female
gen bl_kstock_female=bl_female*bl_kstock

eststo clear
local i=1
foreach var of varlist asset_val_mach_ip asset_val_othtools_ip asset_val_vehi_ip asset_val_furn_ip asset_val_oth_ip asset_val_stock_ip asset_val_land_ip {

* Panel A: Pooled
* treatment effect with strata and baseline capital
areg `var'_w assign_ent assign_man bl_kstock, r a(bl_stratafinal)
sum `var'_w if e(sample)==1 & assign_control==1 
estadd scalar mean1=r(mean)
test assign_ent=assign_man
estadd scalar pval1=r(p)
eststo tableA9a_`i'

* Panel B: By Gender
areg `var'_w assign_ent_male assign_ent_female assign_man_male assign_man_female bl_female bl_kstock bl_kstock_female, r a(bl_stratafinal)
sum `var'_w if e(sample)==1 & assign_control==1 & bl_female==0
estadd scalar mean1=r(mean)
sum `var'_w if e(sample)==1 & assign_control==1 & bl_female==1
estadd scalar mean2=r(mean)
test assign_ent_male=assign_ent_female
estadd scalar pval2=r(p)
test assign_man_male=assign_man_female
estadd scalar pval3=r(p)
eststo tableA9b_`i'
local i=`i'+1
}

#delimit ;
esttab tableA9a_* using "$output/TableA9.csv", replace depvar legend label nonumbers nogaps
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean1 pval1, fmt(%9.0f %9.0f %9.3f) labels("Sample Size" "Control Mean" "P-value: PI = Trad")) 
	posthead("Panel A: Pooled Sample")
	title("Table A9: Impact on Different Components of Capital Stock") drop(_cons bl_*);
esttab tableA9b_* using "$output/TableA9.csv", append depvar legend label nonumbers nogaps
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean1 mean2 pval2 pval3, fmt(%9.0f %9.0f %9.0f %9.3f %9.3f) labels("Sample Size" "Control Mean Men" "Control Mean Women" "pvalue PI" "pvalue Trad")) 
	posthead("Panel B: Impacts by Gender") drop(_cons bl_*);
#delimit cr


*******************************************************************************
***** Table A10: Heterogeneity in impacts for Women ***************************
*******************************************************************************
 		use "$final/Togoanalysisdata.dta", clear  
eststo clear
local i=1
foreach var of varlist notsoledecisionrev notsoledecisionexp lookafterothers belowmeanedu notmarried {
	reg totalprof5 assign_ent  assign_man assign_ent_`var' assign_man_`var' bl_aprofit `var' bl_aprofit_`var' if bl_female==1, r
	sum `var' if bl_female==1 & e(sample)
	estadd scalar prop1=r(mean)
	sum totalprof5 if e(sample) & `var'==1 & assign_control==1
	estadd scalar mean1=r(mean)
	sum totalprof5 if e(sample) & `var'==0 & assign_control==1
	estadd scalar mean2=r(mean)
	eststo tableA10_`i'
	local i=`i'+1
}
#delimit ;
esttab tableA10_* using "$output/TableA10.csv", replace depvar legend label nonumbers nogaps
	b(a2) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N prop1 mean1 mean2, fmt(%9.0f %9.2f %9.0f %9.0f) labels("Sample Size" "Proportion with Interaction=1" "Control Mean for Interaction=1" "Control Mean for Interaction=0")) 
	title("Table A10: Heterogeneity in Impacts for Women") drop(_cons  bl_* notsoledecisionrev notsoledecisionexp lookafterothers belowmeanedu notmarried);
#delimit cr
