**** Purpose: this file reconciles the phone and in-person long-run surveys, and then merges in short-run data to create long-run dataset 
*** Inputs: final_dataset_ipv2.dta, final_dataset_psv2.dta, Shortrundata.dta, nonresponsedata.dta 
*** Output: Longrundata.dta  
	
	clear all
	set maxvar 32000
	
	/*
	* Setting up globals
	if "`c(username)'" == "wb200090" {
	global raw "~/Dropbox/Togo WB/Analysis/Data/Raw data"
	global intermediate "~/Dropbox/Togo WB/Analysis/Data/Intermediate data"
	global final_data "~/Dropbox/Togo WB/Analysis/Data/Final data"
	}
	*/
	
	**************************************
	* Reconciliation merging the dataset *
	**************************************
	
	* We load the in-person data
	
	use "$raw/final_dataset_ipv2.dta", clear
	
	* We load the other dataset
	
	merge 1:1 id_ent using "$raw/final_dataset_psv2.dta"
	drop _merge
	
	merge 1:1 id_ent using "$intermediate/Shortrundata.dta"
	drop _merge
	
	****************************************************
	* Pre analysis computation section - balance tests *
	****************************************************
	
	* Treatment group
	
	tab treatment_group
	lab var treatment_group "Treatment group"
	
	gen treat_entrepreneurial = .
	replace treat_entrepreneurial = 0 if treatment_group == 1
	replace treat_entrepreneurial = 1 if treatment_group == 2
	lab var treat_entrepreneurial "Treatment Entrepreneurial vs. Control"
	
	gen treat_managerial = .
	replace treat_managerial = 0 if treatment_group == 1
	replace treat_managerial = 1 if treatment_group == 3
	lab var treat_managerial "Treatment Managerial vs. Control"
	
	
	* Single group dummy (response rate)
	cap drop control_group entrepreneurial_group managerial_group
	gen control_group = (treatment_group == 1)
	lab var control_group "Control response rate"
	
	gen assign_control = 0
	replace assign_control = 1 if assign_ent == 0 & assign_man == 0
	
	gen entrepreneurial_group = (treatment_group == 2)
	lab var entrepreneurial_group "Entrepreneurial (PI) response rate"
	
	gen managerial_group = (treatment_group == 3)
	lab var managerial_group "Managerial (Traditional) response rate"
	
	* Not found recoded as deceased following discussion with PIs
	
	* We code the response_rate
	
	gen response_rate_ip = 0
	replace response_rate_ip = 1 if final_status_ip == 1
	lab var response_rate_ip "Response rate in-person survey"
	
	gen response_rate_ps = 0
	replace response_rate_ps = 1 if final_status_ps == 1
	lab var response_rate_ps "Response rate phone survey"
	
	* Creating response rate data
	
	gen response_rate_at_ip_ps = 0
	replace response_rate_at_ip_ps = 1 if response_rate_ip == 1 | response_rate_ps == 1
	lab var response_rate_at_ip_ps "Response rate either in-person or phone survey"
	
	gen response_rate_ip_ps = 0
	replace response_rate_ip_ps = 1 if response_rate_ip == 1 & response_rate_ps == 1
	lab var response_rate_ip_ps "Response rate both surveys"
	
	* Baseline variables
	
	sum win_bl_profits_lm bl_commerce bl_production bl_female bl_age bl_years_schooling bl_firm_age win_bl_sales_lm win_bl_sales_lw  win_bl_profits_lw  bl_no_workers win_bl_k_stock  PI_bl bl_business_practice
	
	* Creating subgroup from round 4
	
	replace open_company_fu4 = 1 if closed_company_ps == 1 & open_company_fu4 == . | closed_company_ip == 1 & open_company_fu4 == .
	
	sum win_fu4_total_profits, d
	gen fu4_win_profits_med = (win_fu4_total_profits >= `r(p50)')
	
	replace fu4_win_profits_med = . if win_fu4_total_profits == .
	lab var fu4_win_profits_med "Profits above the median in FU4"
	
	gen fu4_win_profits_med_i = fu4_win_profits_med
	byso bl_stratafinal: egen temp = mean(fu4_win_profits_med)
	replace fu4_win_profits_med_i = temp if fu4_win_profits_med == .
	
	***********************************************
	* Pre analysis computation section - outcomes *
	***********************************************
	
	****************
	* Final status *
	****************
	
	gen final_status_as = final_status_ip
	replace final_status_as = final_status_ps if final_status_as == .
	lab val final_status_as final_status
	
	*********************
	* Employment status *
	*********************
	
	foreach var in current_emp_status_1 current_emp_status_2 current_emp_status_3 current_emp_status_4 current_emp_status_5 current_emp_status_6 current_emp_status_7 current_emp_status_8 {
	
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		replace `var'_as = 0 if final_status_as == 6
		
		}
			
	******************
	* Closed company *
	******************
	
	* Creating one for IP or PS name AS
	
	foreach var in closed_company closed_company_1 closed_company_2 closed_company_3 closed_company_4 {
		
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		
		}
	
	******************
	* Closing reason *
	******************
	
	foreach var in mainbusi_closing_reason_1 mainbusi_closing_reason_2 mainbusi_closing_reason_3 mainbusi_closing_reason_7 mainbusi_closing_reason_13 {
		
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		replace `var'_as = . if !inlist(closed_company_as,1,2,-98)
		
		byso strata: egen temp_`var' =  mean(`var'_as)
		replace `var'_as = temp_`var' if inlist(closed_company_as,1,2,-98) & mainbusi_closing_reason == .
		drop temp_`var'
		
		byso treatment_group: egen temp_`var' =  mean(`var'_as)
		replace `var'_as = temp_`var' if inlist(closed_company_as,1,2,-98) & mainbusi_closing_reason == .
		drop temp_`var'
		
		}
	
	****************************************************************
	* Employee in the main company (conditional and unconditional) *
	****************************************************************
	
	* Creating one for IP or PS name AS
	
	foreach var in mainbusi_num_employee p_mainbusi_num_pemployee p_mainbusi_num_aemployee p_mainbusi_num_nemployee mainbusi_num_employee20 {
		
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		
		gen `var'_uc_as = `var'_uc_ip
		replace `var'_uc_as = `var'_uc_ps if `var'_uc_as == .
		
		replace `var'_as = 0 if final_status_as == 6
		replace `var'_uc_as = 0 if final_status_as == 6
		
		}
	
	gen mainbusi_num_paidemployee_as=mainbusi_num_paidemployee_ip
	replace mainbusi_num_paidemployee_as=mainbusi_num_paidemployee_ps if mainbusi_num_paidemployee_as==.
	replace mainbusi_num_paidemployee_as=0 if final_status_as==6
	
	*****************************
	* Number of other companies *
	*****************************
	
	* Creating one for IP or PS name AS
	
	foreach var in othbusi_num_company othbusi_al1_company busi_al1_open {
		
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		replace `var'_as = 0 if final_status_as == 6
		
		}
	
	lab var busi_al1_open_as "At least 1 company including original business"
	
	
	**************************
	** Life Satisfaction     *
	**************************
	
	gen satisfaction_ladder_as=satisfaction_ladder_ip
	replace satisfaction_ladder_as=life_statisfaction if satisfaction_ladder_as==.
	label var satisfaction_ladder_as "Life Satisfaction on Cantril Ladder"
	
	
	**************************
	* Main business activity *
	**************************
	
	gen refusal_still_owner_as = (refusal_still_owner_ps == 1 | refusal_still_owner_ip == 1)
	
	* Consent variable
	
	gen consent_as = (consent_ip == 1 | consent_ps == 1)
	
	* Creating one for IP or PS name AS
	
	foreach var in mainbusi_totsale_lastmonth mainbusi_totsale_bestmonth mainbusi_totsale_wmonth mainbusi_totprof_lastmonth mainbusi_totprof_bestmonth mainbusi_totprof_wmonth {
		
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		replace `var'_as = 0 if final_status_as == 6
		replace `var'_as = 0 if refusal_still_owner_as == 1
		
		}
	
	* 2019 recall of profits and sales from IP
	foreach var in totsal_bestm19_best_ip totsal_worstm19_best_ip totprof_bestm19_best_ip totprof_worstm19_best_ip totsaloth_bestm19_best_ip totsaloth_worstm19_best_ip totprofoth_bestm19_best_ip totprofoth_worstm19_best_ip {
		destring `var', force replace
		gen `var'_usd=`var'/550.50
	}
	
	
	* Profit and sales winsorization and conversion USD
	
	foreach suffix in ip ps as {
	
		foreach var in mainbusi_totsale_lastmonth mainbusi_totsale_bestmonth mainbusi_totsale_wmonth mainbusi_totprof_lastmonth mainbusi_totprof_bestmonth mainbusi_totprof_wmonth {
			
			* Missing dummy
			
			gen `var'_`suffix'_mi = (`var'_`suffix' == . & consent_`suffix' == 1)
			lab var `var'_`suffix'_mi "Missing dummy for `var' in `suffix' survey"
			
			* Imputation
			
			replace `var'_`suffix' = 0 if consent_`suffix' == 1 & `var'_`suffix' == . & closed_company_2_`suffix' != 2
			replace `var'_`suffix' = 0 if final_status_`suffix' == 6
			replace `var'_`suffix' = 0 if refusal_still_owner_`suffix' == 1
			
			* Winsorization
			
			winsor2 `var'_`suffix', suffix(_w) cuts(1 99)
			gen `var'_`suffix'_wu = `var'_`suffix'_w / 550.50
			
			}
			
		}
	
	foreach suffix in ip ps as {
	
		lab var mainbusi_totsale_lastmonth_`suffix'_w "Main Company `suffix' - Total sale in last month in XOF (best estimate - w 1-99)"
		lab var mainbusi_totsale_lastmonth_`suffix'_wu "Main Company `suffix' - Total sale in last month in USD (best estimate - w 1-99)"

		lab var mainbusi_totsale_bestmonth_`suffix'_w "Main Company `suffix' - Total sale in best month 2020 in XOF (best estimate - w 1-99)"
		lab var mainbusi_totsale_bestmonth_`suffix'_wu "Main Company `suffix' - Total sale in best month 2020 in USD (best estimate - w 1-99)"
		
		lab var mainbusi_totsale_wmonth_`suffix'_w "Main Company `suffix' - Total sale in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var mainbusi_totsale_wmonth_`suffix'_wu "Main Company `suffix' - Total sale in worst month 2020 in USD (best estimate - w 1-99)"
		
		lab var mainbusi_totprof_lastmonth_`suffix'_w "Main Company `suffix' - Total profit in last month in XOF (best estimate - w 1-99)"
		lab var mainbusi_totprof_lastmonth_`suffix'_wu "Main Company `suffix' - Total profit in last month in USD (best estimate - w 1-99)"

		lab var mainbusi_totprof_bestmonth_`suffix'_w "Main Company `suffix' - Total profit in best month 2020 in XOF (best estimate - w 1-99)"
		lab var mainbusi_totprof_bestmonth_`suffix'_wu "Main Company `suffix' - Total profit in best month 2020 in USD (best estimate - w 1-99)"
		
		lab var mainbusi_totprof_wmonth_`suffix'_w "Main Company `suffix' - Total profit in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var mainbusi_totprof_wmonth_`suffix'_wu "Main Company `suffix' - Total profit in worst month 2020 in USD (best estimate - w 1-99)"
		
		}
		
	********************
	* Other activities *
	********************
	
	* Creating one for IP or PS name AS
	
	foreach var in othbusi_totsale_lastmonth othbusi_totsale_bestmonth othbusi_totsale_wmonth othbusi_totprof_lastmonth othbusi_totprof_bestmonth othbusi_totprof_wmonth {
		
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		
		}
	
	foreach suffix in ip ps as {
		
		gen othbusi_avgtotsale_lmonth_`suffix' = othbusi_totsale_lastmonth_`suffix' / othbusi_num_company_`suffix'
		
		gen othbusi_avgtotsale_bmonth_`suffix' = othbusi_totsale_bestmonth_`suffix' / othbusi_num_company_`suffix'
		
		gen othbusi_avgtotsale_wmonth_`suffix' = othbusi_totsale_wmonth_`suffix' / othbusi_num_company_`suffix'
		
		gen othbusi_avgtotprof_lmonth_`suffix' = othbusi_totprof_lastmonth_`suffix' / othbusi_num_company_`suffix'
		
		gen othbusi_avgtotprof_bmonth_`suffix' = othbusi_totprof_bestmonth_`suffix' / othbusi_num_company_`suffix'
			
		gen othbusi_avgtotprof_wmonth_`suffix' = othbusi_totprof_wmonth_`suffix' / othbusi_num_company_`suffix'
		
		}
	

	foreach suffix in ip ps as {
	
		foreach var in othbusi_totsale_lastmonth othbusi_avgtotsale_lmonth othbusi_totsale_bestmonth othbusi_avgtotsale_bmonth othbusi_totsale_wmonth othbusi_avgtotsale_wmonth othbusi_totprof_lastmonth othbusi_avgtotprof_lmonth othbusi_totprof_bestmonth othbusi_avgtotprof_bmonth othbusi_totprof_wmonth othbusi_avgtotprof_wmonth {
			
			gen `var'_`suffix'_mi = (`var'_`suffix' == . & consent_`suffix' == 1)
			lab var `var'_`suffix'_mi "Missing dummy for `var' in `suffix' survey"
			
			* Imputation
			
			replace `var'_`suffix' = 0 if consent_`suffix' == 1 & `var'_`suffix' == . & othbusi_num_company_`suffix' == 0
			replace `var'_`suffix' = 0 if final_status_`suffix' == 6
			replace `var'_`suffix' = 0 if refusal_still_owner_`suffix' == 1
			
			* Winsorization
			
			winsor2 `var'_`suffix', suffix(_w) cuts(1 99)
			gen `var'_`suffix'_wu = `var'_`suffix'_w / 550.50
		
			}
			
		}
	
	foreach suffix in ip ps as {
	
		lab var othbusi_totsale_lastmonth_`suffix'_w "Other Companies `suffix' - Total sale in last month in XOF (best estimate - w 1-99)"
		lab var othbusi_totsale_lastmonth_`suffix'_wu "Other Companies `suffix' - Total sale in last month in USD (best estimate - w 1-99)"
		lab var othbusi_avgtotsale_lmonth_`suffix'_w "Other Companies `suffix' - Average total sale in last month in XOF (best estimate - w 1-99)"
		lab var othbusi_avgtotsale_lmonth_`suffix'_wu "Other Companies `suffix' - Average total sale in last month in USD (best estimate - w 1-99)"

		lab var othbusi_totsale_bestmonth_`suffix'_w "Other Companies `suffix' - Total sale in best month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_totsale_bestmonth_`suffix'_wu "Other Companies `suffix' - Total sale in best month 2020 in USD (best estimate - w 1-99)"
		lab var othbusi_avgtotsale_bmonth_`suffix'_w "Other Companies `suffix' - Average total sale in best month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_avgtotsale_bmonth_`suffix'_wu "Other Companies `suffix' - Average total sale in best month 2020 in USD (best estimate - w 1-99)"

		lab var othbusi_totsale_wmonth_`suffix'_w "Other Companies `suffix' - Total sale in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_totsale_wmonth_`suffix'_wu "Other Companies `suffix' - Total sale in worst month 2020 in USD (best estimate - w 1-99)"
		lab var othbusi_avgtotsale_wmonth_`suffix'_w "Other Companies `suffix' - Average total sale in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_avgtotsale_wmonth_`suffix'_wu "Other Companies `suffix' - Average total sale in worst month 2020 in USD (best estimate - w 1-99)"

		lab var othbusi_totprof_lastmonth_`suffix'_w "Other Companies `suffix' - Total profit in last month in XOF (best estimate - w 1-99)"
		lab var othbusi_totprof_lastmonth_`suffix'_wu "Other Companies `suffix' - Total profit in last month in USD (best estimate - w 1-99)"
		lab var othbusi_avgtotprof_lmonth_`suffix'_w "Other Companies `suffix' - Average Total profit in last month in XOF (best estimate - w 1-99)"
		lab var othbusi_avgtotprof_lmonth_`suffix'_wu "Other Companies `suffix' - Average Total profit in last month in USD (best estimate - w 1-99)"

		lab var othbusi_totprof_bestmonth_`suffix'_w "Other Companies `suffix' - Total profit in best month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_totprof_bestmonth_`suffix'_wu "Other Companies `suffix' - Total profit in best month 2020 in USD (best estimate - w 1-99)"
		lab var othbusi_avgtotprof_bmonth_`suffix'_w "Other Companies `suffix' - Average Total profit in best month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_avgtotprof_bmonth_`suffix'_wu "Other Companies `suffix' - Average Total profit in best month 2020 in USD (best estimate - w 1-99)"

		lab var othbusi_totprof_wmonth_`suffix'_w "Other Companies `suffix' - Total profit in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_totprof_wmonth_`suffix'_wu "Other Companies `suffix' - Total profit in worst month 2020 in USD (best estimate - w 1-99)"
		lab var othbusi_avgtotprof_wmonth_`suffix'_w "Other Companies `suffix' - Average Total profit in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var othbusi_avgtotprof_wmonth_`suffix'_wu "Other Companies `suffix' - Average Total profit in worst month 2020 in USD (best estimate - w 1-99)"
		
		}
	
	********************************************************************
	* Total profits of all businesses (winsorization + conversion USD) *
	********************************************************************
	
	* Creating the data
	
	foreach suffix in ip ps as {
	
		egen allbusi_totprof_lastmonth_`suffix' = rowtotal(mainbusi_totprof_lastmonth_`suffix' othbusi_totprof_lastmonth_`suffix') if consent_`suffix' == 1, m
		sum allbusi_totprof_lastmonth_`suffix'
		
		gen allbusi_totprof_lastmonth_`suffix'_mi = 0 if consent_`suffix' == 1
		replace allbusi_totprof_lastmonth_`suffix'_mi = 1 if mainbusi_totprof_lastmonth_`suffix'_mi == 1 & othbusi_totprof_lastmonth_`suffix'_mi == 1
		replace allbusi_totprof_lastmonth_`suffix'_mi = 0 if final_status_`suffix' == 6
		replace allbusi_totprof_lastmonth_`suffix'_mi = 0 if refusal_still_owner_`suffix' == 1
			
		egen allbusi_totprof_bestmonth_`suffix' = rowtotal(mainbusi_totprof_bestmonth_`suffix' othbusi_totprof_bestmonth_`suffix') if consent_`suffix' == 1, m
		sum allbusi_totprof_bestmonth_`suffix'
		
		gen allbusi_totprof_bestmonth_`suffix'_mi = 0 if consent_`suffix' == 1
		replace allbusi_totprof_bestmonth_`suffix'_mi = 1 if mainbusi_totprof_bestmonth_`suffix'_mi == 1 & othbusi_totprof_bestmonth_`suffix'_mi == 1
		replace allbusi_totprof_bestmonth_`suffix'_mi = 0 if final_status_`suffix' == 6
		replace allbusi_totprof_bestmonth_`suffix'_mi = 0 if refusal_still_owner_`suffix' == 1
		
		egen allbusi_totprof_wmonth_`suffix' = rowtotal(mainbusi_totprof_wmonth_`suffix' othbusi_totprof_wmonth_`suffix') if consent_`suffix' == 1, m
		sum allbusi_totprof_wmonth_`suffix'
		
		gen allbusi_totprof_wmonth_`suffix'_mi = 0 if consent_`suffix' == 1
		replace allbusi_totprof_wmonth_`suffix'_mi = 1 if mainbusi_totprof_wmonth_`suffix'_mi == 1 & othbusi_totprof_wmonth_`suffix'_mi == 1
		replace allbusi_totprof_wmonth_`suffix'_mi = 0 if final_status_`suffix' == 6
		replace allbusi_totprof_wmonth_`suffix'_mi = 0 if refusal_still_owner_`suffix' == 1
		
		}
		
	foreach suffix in ip ps as {
	
		foreach var in allbusi_totprof_lastmonth allbusi_totprof_bestmonth allbusi_totprof_wmonth {
		
			* Missing dummy
			
			lab var `var'_`suffix'_mi "Missing dummy for `var'"
			
			* Imputation
			
			replace `var'_`suffix' = 0 if consent_`suffix' == 1 & `var'_`suffix' == . & closed_company_2_`suffix' == 1 | consent_`suffix' == 1 & `var'_`suffix' == . & othbusi_num_company_`suffix' == 0
			replace `var'_`suffix' = 0 if final_status_`suffix' == 6
			replace `var'_`suffix' = 0 if refusal_still_owner_`suffix' == 1
			
			* Winsorization
			
			winsor2 `var'_`suffix', suffix(_w) cuts(1 99)
			gen `var'_`suffix'_wu = `var'_`suffix'_w / 550.50
			
			}
			
		}
		
	foreach suffix in ip ps as {
	
		lab var allbusi_totprof_lastmonth_`suffix'_w "All Companies `suffix' - Total profits in last month in XOF (best estimate - w 1-99)"
		lab var allbusi_totprof_lastmonth_`suffix'_wu "All Companies `suffix' - Total profits in last month in USD (best estimate - w 1-99)"
		
		lab var allbusi_totprof_bestmonth_`suffix'_w "All Companies `suffix' - Total profits in best month in XOF (best estimate - w 1-99)"
		lab var allbusi_totprof_bestmonth_`suffix'_wu "All Companies `suffix' - Total profits in best month in USD (best estimate - w 1-99)"
		
		lab var allbusi_totprof_wmonth_`suffix'_w "All Companies `suffix' - Total profits in worst month in XOF (best estimate - w 1-99)"
		lab var allbusi_totprof_wmonth_`suffix'_wu "All Companies `suffix' - Total profits in worst month in USD (best estimate - w 1-99)"
		
		}
	
	*********************************
	* Other activities with revenus *
	*********************************
	
	* Creating one for IP or PS name AS
	
	foreach var in othact_d othact_num othact_totrev_lastmonth othact_totrev_bestmonth othact_totrev_wmonth {
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		
		}
	
	foreach suffix in ip ps as {
		
		gen othact_avgtotrev_lmonth_`suffix' = othact_totrev_lastmonth_`suffix' / othact_num_`suffix'
		
		gen othact_avgtotrev_bmonth_`suffix' = othact_totrev_bestmonth_`suffix' / othact_num_`suffix'
		
		gen othact_avgtotrev_wmonth_`suffix' = othact_totrev_wmonth_`suffix' / othact_num_`suffix'
		
		
		}
	
	foreach suffix in ip ps as {
	
		foreach var in othact_d {
		
			replace `var'_`suffix' = 0 if final_status_`suffix' == 6 
			replace `var'_`suffix' = 0 if refusal_still_owner_`suffix' == 1
			
			}
		
		}
		
	foreach suffix in ip ps as {
	
		foreach var in othact_num {
		
			replace `var'_`suffix' = 0 if final_status_`suffix' == 6
			replace `var'_`suffix' = 0 if refusal_still_owner_`suffix' == 1
			replace `var'_`suffix' = 0 if othact_d_`suffix' == 0
			
			}
		
		}
	
	foreach suffix in ip ps as {
	
		foreach var in othact_totrev_lastmonth othact_totrev_bestmonth othact_totrev_wmonth othact_avgtotrev_lmonth othact_avgtotrev_bmonth othact_avgtotrev_wmonth{
			gen `var'_`suffix'_mi = (`var'_`suffix' == . & consent_`suffix' == 1)
			lab var `var'_`suffix'_mi "Missing dummy for `var' in `suffix' survey"
			
			* Imputation
			
			replace `var'_`suffix' = 0 if consent_`suffix' == 1 & `var'_`suffix' == . & othact_d_`suffix' == 0
			replace `var'_`suffix' = . if consent_`suffix' == 1 & othact_d_`suffix' == .
			replace `var'_`suffix' = 0 if final_status_`suffix' == 6
			replace `var'_`suffix' = 0 if refusal_still_owner_`suffix' == 1
						
			* Winsorization
			
			winsor2 `var'_`suffix', suffix(_w) cuts(1 99)
			gen `var'_`suffix'_wu = `var'_`suffix'_w / 550.50
		
			}
			
		}
	
	foreach suffix in ip ps as {
	
		lab var othact_totrev_lastmonth_`suffix'_w "Other Activities `suffix' - Total revenue in last month in XOF (best estimate - w 1-99)"
		lab var othact_totrev_lastmonth_`suffix'_wu "Other Activities `suffix' - Total revenue in last month in USD (best estimate - w 1-99)"
		lab var othact_avgtotrev_lmonth_`suffix'_w "Other Activities `suffix' - Average total revenue in last month in XOF (best estimate - w 1-99)"
		lab var othact_avgtotrev_lmonth_`suffix'_wu "Other Activities `suffix' - Average total revenue in last month in USD (best estimate - w 1-99)"

		lab var othact_totrev_bestmonth_`suffix'_w "Other Activities `suffix' - Total revenue in best month 2020 in XOF (best estimate - w 1-99)"
		lab var othact_totrev_bestmonth_`suffix'_wu "Other Activities `suffix' - Total revenue in best month 2020 in USD (best estimate - w 1-99)"
		lab var othact_avgtotrev_bmonth_`suffix'_w "Other Activities `suffix' - Average total revenue in best month 2020 in XOF (best estimate - w 1-99)"
		lab var othact_avgtotrev_bmonth_`suffix'_wu "Other Activities `suffix' - Average total revenue in best month 2020 in USD (best estimate - w 1-99)"

		lab var othact_totrev_wmonth_`suffix'_w "Other Activities `suffix' - Total revenue in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var othact_totrev_wmonth_`suffix'_wu "Other Activities `suffix' - Total revenue in worst month 2020 in USD (best estimate - w 1-99)"
		lab var othact_avgtotrev_wmonth_`suffix'_w "Other Activities `suffix' - Average total revenue in worst month 2020 in XOF (best estimate - w 1-99)"
		lab var othact_avgtotrev_wmonth_`suffix'_wu "Other Activities `suffix' - Average total revenue in worst month 2020 in USD (best estimate - w 1-99)"

		}
		
	*************************************************************************************
	* Total profits of all businesses + Total revenues (winsorization + conversion USD) *
	*************************************************************************************
	
	* Creating new variables
	
	foreach suffix in ip ps as {
	
		egen allbusinc_totrev_lastmonth_`suffix' = rowtotal(allbusi_totprof_lastmonth_`suffix' othact_totrev_lastmonth_`suffix'), m
		lab var allbusinc_totrev_lastmonth_`suffix' "All Companies and Activities - Total revenues in last month in XOF (best estimate)"
		
		gen allbusinc_totrev_lastmonth_`suffix'_mi = 0 if consent_`suffix' == 1
		replace allbusinc_totrev_lastmonth_`suffix'_mi = 1 if allbusi_totprof_lastmonth_`suffix'_mi == 1 & othact_totrev_lastmonth_`suffix'_mi == 1
		replace allbusinc_totrev_lastmonth_`suffix'_mi = 1 if final_status_`suffix' == 6
		replace allbusinc_totrev_lastmonth_`suffix'_mi = 1 if refusal_still_owner_`suffix' == 1
		
		egen allbusinc_totrev_bestmonth_`suffix' = rowtotal(allbusi_totprof_bestmonth_`suffix' othact_totrev_bestmonth_`suffix'), m
		lab var allbusinc_totrev_bestmonth_`suffix' "All Companies and Activities - Total revenues in best month 2020 in XOF (best estimate)"
		
		gen allbusinc_totrev_bestmonth_`suffix'_mi = 0 if consent_`suffix' == 1
		replace allbusinc_totrev_bestmonth_`suffix'_mi = 1 if allbusi_totprof_bestmonth_`suffix'_mi == 1 & othact_totrev_bestmonth_`suffix'_mi == 1
		replace allbusinc_totrev_bestmonth_`suffix'_mi = 1 if final_status_`suffix' == 6
		replace allbusinc_totrev_bestmonth_`suffix'_mi = 1 if refusal_still_owner_`suffix' == 1
		
		egen allbusinc_totrev_wmonth_`suffix' = rowtotal(allbusi_totprof_wmonth_`suffix' othact_totrev_wmonth_`suffix'), m
		lab var allbusinc_totrev_wmonth_`suffix' "All Companies and Activities - Total revenues in worst month 2020 in XOF (best estimate)"
		
		gen allbusinc_totrev_wmonth_`suffix'_mi = 0 if consent_`suffix' == 1
		replace allbusinc_totrev_wmonth_`suffix'_mi = 1 if allbusi_totprof_wmonth_`suffix'_mi == 1 & othact_totrev_wmonth_`suffix'_mi == 1
		replace allbusinc_totrev_wmonth_`suffix'_mi = 1 if final_status_`suffix' == 6
		replace allbusinc_totrev_wmonth_`suffix'_mi = 1 if refusal_still_owner_`suffix' == 1
		
		}
			
	foreach suffix in ip ps as {
		
		foreach var in allbusinc_totrev_lastmonth allbusinc_totrev_bestmonth allbusinc_totrev_wmonth {
		
			* Missing dummy
			
			lab var `var'_`suffix'_mi "Missing dummy for `var'"
			
			* Imputation
			
			replace `var'_`suffix' = 0 if consent_`suffix' == 1 & `var'_`suffix' == . & othact_d_`suffix' == 0 | consent_`suffix' == 1 & `var'_`suffix' == . & closed_company_2_`suffix' == 1 | consent_`suffix' == 1 & `var'_`suffix' == . & othbusi_num_company_`suffix' == 0
			replace `var'_`suffix' = . if consent_`suffix' == 1 & othact_d_`suffix' == .
			replace `var'_`suffix' = 0 if final_status_`suffix' == 6
			replace `var'_`suffix' = 0 if refusal_still_owner_`suffix' == 1
			
			* Winsorization
			
			winsor2 `var'_`suffix', suffix(_w) cuts(1 99)
			gen `var'_`suffix'_wu = `var'_`suffix'_w / 550.50
			
			
			}
		
		lab var allbusinc_totrev_lastmonth_`suffix'_w "All Companies and Activities - Total revenues in last month in XOF (best estimate - w 1-99)"
		lab var allbusinc_totrev_lastmonth_`suffix'_wu "All Companies and Activities - Total revenues in last month in USD (best estimate - w 1-99)"
		
		lab var allbusinc_totrev_bestmonth_`suffix'_w "All Companies and Activities - Total revenues in best month in XOF (best estimate - w 1-99)"
		lab var allbusinc_totrev_bestmonth_`suffix'_wu "All Companies and Activities - Total revenues in best month in USD (best estimate - w 1-99)"
		
		lab var allbusinc_totrev_wmonth_`suffix'_w "All Companies and Activities- Total revenues in worst month in XOF (best estimate - w 1-99)"
		lab var allbusinc_totrev_wmonth_`suffix'_wu "All Companies and Activities  - Total revenues in worst month in USD (best estimate - w 1-99)"
		
	}
	
	******************************
	* Persional initiative index *
	******************************
	
	* Creating new variables
	
	foreach var in pi_index persoinit_b persoinit_f persoinit_h persoinit_j persoinit_l {
		gen `var'_as = `var'_ip
		replace `var'_as = `var'_ps if `var'_as == .
		
		}
		
	***************************************
	* Creating a variable for dead people *
	***************************************
	
	* Creating a new variables
	
	gen dead_as = (final_status_ip==6 | final_status_ps==6)
	lab var dead_as "Dummy var if respondent is reported dead in the PS or IP survey"

	* Composite answer
	
	gen response_rate_comp = response_rate_at_ip_ps
	replace response_rate_comp = 1 if dead_as == 1
	replace response_rate_comp = 1 if refusal_still_owner_ps == 1 | refusal_still_owner_ip == 1
	lab var response_rate_comp "Response rate composite of consent, death and refusal but owner"
	
	
	*** merge in data collected on non-responses
	sort id_ent
	merge id_ent using "$raw/nonresponsedata.dta"
	tab _merge
	drop _merge
	sort id_ent
	* We save the dataset
	
	save "$intermediate/Longrundata.dta", replace
