
**** Purpose: this file takes the master data set from the short-run follow-ups and baseline, and extracts the variables needed for this long-run paper

*** Inputs: Master_data_sr.dta
*** Output: Shortrundata.dta  

	
	* We load the dataset
	
	use "$intermediate/Master_data_sr.dta", clear
	
	gen bl_stratafinal=strata
	
	* Creating open company in follow-up 4
	
	gen open_company_fu4 = .
	replace open_company_fu4 = 0 if fu4_p2q2 != 1 & fu4_p2q2 != .
	replace open_company_fu4 = 1 if fu4_p2q2 == 1
	replace open_company_fu4 = 0 if fu3_p2q2 != 1 & fu3_p2q2 != . & open_company_fu4 == .
	replace open_company_fu4 = 0 if fu2_p2q2 != 1 & fu2_p2q2 != . & open_company_fu4 == .
	replace open_company_fu4 = 0 if fu1_p2q1 != 1 & fu1_p2q1 != . & open_company_fu4 == .
	lab var open_company_fu4 "Open company during follow-up 4"
	
	gen open_company_fu4_i = open_company_fu4
	byso bl_stratafinal: egen temp = mean(open_company_fu4)
	replace open_company_fu4_i = temp if open_company_fu4 == .
	drop temp
	
	lab var bl_no_workers "Number of workers in the company at baseline"
	label var PI_fu4 "PI in FU4"
	
	* baseline self-efficacy
sum bl_q138a- bl_q138i
alpha bl_q138a- bl_q138i, item
egen bl_selfefficacy=rowmean(bl_q138a- bl_q138i)
sum bl_selfefficacy
label var bl_selfefficacy "Baseline self-efficacy"

* follow-up 4 self-efficacy
sum fu4_p4q13a- fu4_p4q13i
alpha fu4_p4q13a- fu4_p4q13i, item
egen fu4_selfefficacy=rowmean(fu4_p4q13a- fu4_p4q13i)
sum fu4_selfefficacy
label var fu4_selfefficacy "Self-efficacy in FU4"

* Check survival, profits, sales,  total profits, capital stock, other income, number of other firms to bring forward for panel analysis
sum win_fu*_sales_lm win_fu*_profits_lm
sum win_bl_total_profits win_fu*_total_profits
sum fu1_has_business fu2_has_business fu3_has_business fu4_has_business
sum win_bl_k_stock win_fu2_k_stock win_fu3_k_stock win_fu4_k_stock 
sum win_bl_stock_value win_fu1_stock_value win_fu2_stock_value win_fu3_stock_value win_fu4_stock_value
sum PI_fu1 PI_fu2 PI_fu3 PI_fu4
gen fu4_numberotherfirms=fu4_p4q1
gen fu3_numberotherfirms=fu3_p5q1
gen fu2_numberotherfirms=fu2_p5q1
gen fu1_numberotherfirms=fu1_p5q1
gen fu4_otherincome=fu4_p4q3aii
replace fu4_otherincome=0 if fu4_p4q3==2
gen fu3_otherincome=fu3_p5q3aii
replace fu3_otherincome=0 if fu3_p5q3==0
gen fu2_otherincome=fu2_p5q2aii
replace fu2_otherincome=0 if fu2_p5q2==0
gen fu1_otherincome=fu1_p5q3aii
replace fu1_otherincome=0 if fu1_p5q3==2
* convert into 2014 CFA using CPI
replace fu1_otherincome=fu1_otherincome/100.1809
replace fu2_otherincome=fu2_otherincome/100.37132
replace fu3_otherincome=fu3_otherincome/101.97115
replace fu4_otherincome=fu4_otherincome/101.41864
* winsorize other income
for num 1/4: winsor2 fuX_otherincome, suffix(_w) cuts(1 99)
for num 1/4: rename fuX_otherincome_w win_fuX_otherincome


***Capital Stock Including inventories and with/without land and buildings

gen bl_kstock1=bl_k_stock+bl_stock_value
label var bl_kstock1 "Baseline capital in CFA including land and buildings"
gen bl_kstock2=bl_kstock1
replace bl_kstock2=bl_kstock1-bl_q86e2 if bl_q86e2~=.
label var bl_kstock2 "Baseline capital in CFA excluding land and buildings"

sum bl_kstock1 bl_kstock2

egen fu4_kstock1=rsum(fu4_p3q36a2 fu4_p3q36b2 fu4_p3q36c2 fu4_p3q36d2 fu4_p3q36e2 fu4_p3q36f2)
replace fu4_kstock1=. if fu4_k_stock_miss==6 
replace fu4_kstock1=fu4_kstock1+win_fu4_stock_value if win_fu4_stock_value~=.
label var fu4_kstock1 "Fu4 capital in 2014 CFA including land and buildings"
gen fu4_kstock2=fu4_kstock1
replace fu4_kstock2=fu4_kstock1-fu4_p3q36e2 if fu4_p3q36e2~=.
replace fu4_kstock2=0 if fu4_kstock2<0
label var fu4_kstock2 "Fu4 capital in 2014 CFA excluding land and buildings"


**** PI measures using same subset of questions as long-term follow-up
* Personal initiative scale bl
egen PIss_bl = rowmean (bl_q135k bl_q143j bl_q143q bl_q143u bl_q143y)

* Personal initiative scale fu1
egen PIss_fu1 = rowmean (fu1_p5q18b fu1_p5q18f fu1_p5q18h fu1_p5q18j fu1_p5q18l)
* Personal initiative scale fu2
egen PIss_fu2 = rowmean ( fu2_p5q11b fu2_p5q11d fu2_p5q11e fu2_p5q11f fu2_p5q11g)
*Personal initiative scale fu3
egen PIss_fu3 = rowmean (  fu3_p5q14b  fu3_p5q14f fu3_p5q14h fu3_p5q14j fu3_p5q14l)
*Personal Initiative scale fu4
egen PIss_fu4 = rowmean (fu4_p4q8b  fu4_p4q8f fu4_p4q8h fu4_p4q8j fu4_p4q8l)


**** Business practice index for same 9 variables measured in long-term follow-up 

for num 2/4: egen bpindex_fuX=rowmean(fuX_visit_competitors fuX_asks_customers fuX_offers_promotions fuX_compares_quality fuX_analyzes_performance fuX_changes_presentation fuX_read_sector fuX_written_budget fuX_sales_objectives)
* note baseline does not ask a lot of these practices, so use baseline index as proxy.
* replace with closed firm coding if missing
for num 2/4: replace bpindex_fuX=0 if bpindex_fuX==. & fuX_business_practice==0

	* We keep the relevant data
	 
	keep id_ent assign_group assign_man assign_ent open_company_fu4 win_fu4_total_profits  bl_stratafinal bl_selfefficacy open_company_fu4_i  PI_fu1 PI_fu2 PI_fu3 PI_fu4 fu4_business_practice win_fu*_sales_lm win_fu*_profits_lm bl_total_profits win_fu*_total_profits win_bl_total_profits fu1_has_business fu2_has_business fu3_has_business fu4_has_business win_bl_stock_value win_fu1_stock_value win_fu2_stock_value win_fu3_stock_value win_fu4_stock_value fu*_numberotherfirms win_fu1_otherincome- win_fu4_otherincome win_bl_k_stock win_fu2_k_stock win_fu3_k_stock win_fu4_k_stock fu4_no_workers fu3_no_workers fu2_no_workers fu1_no_workers bl_no_workers bl_k_stock_miss fu1_paid_workers fu2_paid_workers fu3_paid_workers fu4_paid_workers fu4_selfefficacy bl_kstock1 bl_kstock2 fu4_kstock1 fu4_kstock2 PIss* bpindex_* bl_new_products fu1_new_products fu2_new_products fu3_new_products fu4_new_products interviewed_fu* lookafterothers notmarried soledecision*
	
	sort id_ent
	
	save "$intermediate/Shortrundata.dta", replace
	
	

	
