
*****************************************************************************************************
**** Long-term and lasting impacts of personal initiative training on entrepreneurial success   *****
*****************************************************************************************************

************* Master do file ***************************************************************

********************************************************************************************
*                             Housekeeping                                                 *
********************************************************************************************
***NOTE: FOR THE REPLICATION DO-FILES TO RUN CORRECTLY, YOU MUST CREATE A FOLDER FOR REPLICATION THAT HAS: 
	//A SUBFOLDER CALLED "Data", with subfolders "Raw", "Intermediate" and "Final"
	//A SUBFOLDER CALLED "dofile"
	//A SUBFOLDER CALLED "Output", with a subfolder "figures"
	//RAW DATA MUST BE COPIED INTO THE RAW DATA SUBFOLDER
	//ALL DO FILES MUST BE COPIED INTO THE DO-FILE FOLDER
	//YOU MUST ADD YOUR FILE-PATH TO THIS REPLICATION FOLDER IN LINE 30-31 OF THIS DO-FILE (replacing the current text "your name" & "Your filepath to the replication folder here")

drop _all
clear all
set more off, permanently
cap set maxvar 10000
cap set matsize 3000

* Set file paths
   * Main Directory: replace with your filepath
global main "C:\WBG\github\194\Replication\Replication"
* Project folders in his main folder
	global final "$main/Data/Final"
	global output "$main/Output"
	global raw "$main/Data/Raw"
	global intermediate "$main/Data/Intermediate"
	global ado_fldr "$main/ado"
	global dofile "$main/Do files"
	
	
    
    * Make sure any version of ietoolkit is installed.
    * If not, prompt user to install from ssc
    cap which ietoolkit  
    if _rc == 111 {
        di as error "{pstd}You need to have {cmd:ietoolkit} installed to run this reproducibility package. Click {stata ssc install ietoolkit} to do so.{p_end}"
    }
    
    * Make sure installed version of ietoolkit is v7.0 or more recent
    * If not, prompt user to update ietoolkit from ssc
    ietoolkit
    if r(version) < 7.0 {
        di as error "{pstd}You need to update your installation of {cmd:ietoolkit} to run this reproducibility package. Click {stata ado update ietoolkit, update} to do so.{p_end}"
    }    
    
    ieboilstart, version(16.0) adopath("${ado_fldr}", strict) 
	`r(version)'	
	

** Input data **
global Baseline "$raw/BL_raw_an_old"
global Follow_up_1 "$raw/FU1_raw_an_old"
global Follow_up_2 "$raw/FU2_raw_an_old"
global Follow_up_3 "$raw/FU3_raw_an_old"
global Follow_up_4 "$raw/FU4_raw_an_old"
global Master_cleaned "$intermediate/Master_cleaned.dta"
global Master_final "$intermediate/Master_data_sr.dta"


* ======================== *
* Choose sections to run   *
* ======================== * 

global  Construct_SR        0       // Set to 1 if you want to start with the raw short-run data, 0 otherwise
global  Clean_SR            0       // Set to 1 if you want to start with the merged short-run data, 0 otherwise
global  Clean_LR            0       // Set to 1 if you want to start with cleaning the long-run data, 0 otherwise
global	Variable_construct 	0		// Set to 1 if want section run, 0 otherwise
global	Data_Analysis       1		// Set to 1 if want section run, 0 otherwise


********************************************************************************************
********************************************************************************************
*                             Run Do Files                                                 *
********************************************************************************************
********************************************************************************************
if $Construct_SR {
	do "$dofile/ConstructShortrun"
}

if $Clean_SR {
	do "$dofile/CleanShortrundata"
}

if $Clean_LR {
	do "$dofile/CleanLongrundata"
}


if $Variable_construct {
	do "$dofile/VariableConstructionTogo"
}

if $Data_Analysis {
	do "$dofile/AnalysisTogo.do"
}

