
**** Purpose: This file does variable construction for outcomes used in analysis

*** Inputs: longrundata.dta 
*** Output: Togoanalysisdata.dta  (dataset to be used for all Tables and Figures)


	clear all
	set maxvar 32000
	
	/*
	* Setting up globals
	if "`c(username)'" == "wb200090" {
	global final_data "~/Dropbox/Togo WB/Analysis/Data/Final data"
	global output "~/Dropbox/Togo WB/Analysis/Output/DMoutput"
	global raw "~/Dropbox/Togo WB/Analysis/Data/Raw data/"
	global intermediate "~/Dropbox/Togo WB/Analysis/Data/Intermediate data/"
	}
	*/
	
	* Load the dataset
	use "$intermediate/longrundata.dta", clear
	
**** Variables needed for attrition analysis 
 *** Correcting response rates
	* correct composite response measure - know status if closed
	replace response_rate_comp = 1 if refusal_still_owner_ps == 0 | refusal_still_owner_ip == 0
	* update status with firms non-response gives status of opening
	replace response_rate_comp=1 if response_rate_comp==0 & businessopen_nr<=1
	* those who have migrated internationally no longer operating a business in Togo
	replace response_rate_comp=1 if response_rate_comp==0 & intmigrant_nr==1
	* one observation who answered phone survey but somehow miscoded
	replace response_rate_comp=1 if id_ent==5800
	
	** get interview month 
	gen month_ip=substr(date_interview_ip,4,2)
	destring month_ip, force replace
	label var month_ip "Month in-person interview took place"
	replace month_ip=. if response_rate_ip==0
	
    gen new_date_ps = dofc(date_interview_ps)
    format new_date_ps %td
	gen month_ps=month(new_date_ps)
	replace month_ps=. if response_rate_ps~=1
	label var month_ps "Month phone survey took place"
	
	gen month_as=month_ip
	replace month_as=month_ps if month_ip==.
	*those missing date were in short survey of in-person: so date is January 2022
	replace month_as=1 if month_as==. & response_rate_at_ip_ps==1
	
   * generate response groups
   * correct miscode
     replace response_rate_ps=1 if id_ent==5800
   * answers both
    gen respgroup=1 if response_rate_ip==1 & response_rate_ps==1
   * answers only one survey
   replace respgroup=2 if (response_rate_ip==1 & response_rate_ps==0)|(response_rate_ip==0 & response_rate_ps==1)
   * answers neither
    replace respgroup=3 if response_rate_ip==0 & response_rate_ps==0
    gen rgroup2=respgroup==2
    gen rgroup3=respgroup==3

 ** Main activity at long-run follow-up is running a firm
	gen mainactivity=current_emp_status_8_ip
	replace mainactivity=current_emp_status_8_ps if mainactivity==.
	replace mainactivity=0 if dead_as==1
	replace mainactivity=0 if mainactivity==. & (refusal_still_owner_ps == 0 | refusal_still_owner_ip == 0)
	replace mainactivity=1 if mainactivity==. & (refusal_still_owner_ps == 1 | refusal_still_owner_ip == 1)
	replace mainactivity=businessopen_nr if mainactivity==.
	replace mainactivity=0 if intmigrant_nr==1 & mainactivity==.
* replace missing mainactivity for those who just answered very short survey from in-person
   replace mainactivity=1 if closed_company_ip==0 & mainactivity==. 
   replace mainactivity=0 if closed_company_ip~=0 & closed_company_ip~=. & mainactivity==.
   label var mainactivity "Main activity is running a firm"

 ** Self-employed: main activity is self-employed, or still running original firm, or reports profits
  gen selfemployed=mainactivity
  replace selfemployed=1 if closed_company_as==0
  replace selfemployed=1 if allbusi_totprof_lastmonth_as>0 & allbusi_totprof_lastmonth_as~=.	
  label var selfemployed "Self-employed after 7 years"
	
*** Convert baseline variables to USD for balance tables
foreach var of varlist  win_bl_profits_lm win_bl_sales_lm win_bl_sales_lw win_bl_profits_lw win_bl_k_stock {
	gen us_`var'=`var'*(111.7/100)/550.5
}
	
	
*** Robust definitions of still being self-employed for Table A4

*** Under assumptions on business ownership for those unknown
gen selfemployed100=selfemployed
replace selfemployed100=1 if selfemployed==.
gen selfemployed0=selfemployed
replace selfemployed0=0 if selfemployed==.

gen self_miss=selfemployed==.
tab self_miss assign_group
set seed 234
gen random1=uniform()
set sortseed 345
egen rank1=rank(random1), by(assign_group self_miss)
* assume missing are like hard to interview, where 92% self-employed
gen selfemployed92=selfemployed
replace selfemployed92=1 if selfemployed==. & ((rank1<=46 & assign_man==1)|(rank1<=34 & assign_ent==1)|(rank1<=66 & assign_control==1))
replace selfemployed92=0 if selfemployed92==.
* assume half of missing are self-employed
gen selfemployed50=selfemployed
replace selfemployed50=1 if selfemployed==. & ((rank1<=25 & assign_man==1)|(rank1<=19 & assign_ent==1)|(rank1<=36 & assign_control==1))
replace selfemployed50=0 if selfemployed50==.	



******* Defining Key Outcomes ****************
**** Survival 
* Baseline all firms operating
gen survival2013=1
* note: both Fu2 and Fu3 are in 2015 - have taken Fu3 here, since is same month as other rounds
gen survival2014=fu1_has_business
gen survival2015=fu3_has_business
gen survival2016=fu4_has_business
gen survival2021=selfemployed

***** Profits and Sales
*** Total profits and sales in all businesses
gen lastmonthprof=allbusi_totprof_lastmonth_as_wu 
gen bestmonthprof= allbusi_totprof_bestmonth_as_wu  
gen worstmonthprof= allbusi_totprof_wmonth_as_wu 

*** Total sales in all businesses
egen lastmonthsales = rowtotal(mainbusi_totsale_lastmonth_as_wu othbusi_totsale_lastmonth_as_wu), m
egen bestmonthsales = rowtotal(mainbusi_totsale_bestmonth_as_wu othbusi_totsale_bestmonth_as_wu), m
egen worstmonthsales = rowtotal(mainbusi_totsale_wmonth_as_wu othbusi_totsale_wmonth_as_wu), m

* replace profits and sales as zero if missing and not self-employed
foreach var of varlist lastmonthprof bestmonthprof worstmonthprof lastmonthsales bestmonthsales worstmonthsales {
	replace `var'=0 if selfemployed==0 & `var'==.
}

*** Convert all into Sept 2021 USD
** note earlier rounds were already in baseline CFA
* Main and All Profits for Figure 1
gen mprofits2021=mainbusi_totprof_lastmonth_as_wu
gen mprofits2016=win_fu4_profits_lm*(111.7/100)/550.5
gen mprofits2015=((win_fu3_profits_lm*(111.7/100)/550.5)+(win_fu2_profits_lm*(111.7/100)/550.5))/2
gen mprofits2014=win_fu1_profits_lm*(111.7/100)/550.5
gen mprofits2013=win_bl_profits_lm*(111.7/100)/550.5
gen aprofits2021=lastmonthprof
gen aprofits2016=win_fu4_total_profits*(111.7/100)/550.5
gen aprofits2015=((win_fu3_total_profits*(111.7/100)/550.5)+(win_fu2_total_profits*(111.7/100)/550.5))/2
gen aprofits_1_2015=(win_fu3_total_profits*(111.7/100)/550.5)
gen aprofits_2_2015=(win_fu2_total_profits*(111.7/100)/550.5)
gen aprofits2014=win_fu1_total_profits*(111.7/100)/550.5
gen aprofits2013=win_bl_total_profits*(111.7/100)/550.5
* all profits conditional on survival
gen caprofits2013=aprofits2013
gen caprofits2014=aprofits2014 if survival2014==1
gen caprofits2015=aprofits2015 if survival2015==1
gen caprofits2016=aprofits2016 if survival2016==1
gen caprofits2021=aprofits2021 if survival2021==1
gen caprofits_1_2015=aprofits_1_2015 if fu2_has_business==1
gen caprofits_2_2015=aprofits_2_2015 if fu3_has_business==1
* Average all short-term rounds together 
gen m1profits2021=mprofits2021
gen m1profits2016=(mprofits2016+2*mprofits2015+mprofits2014)/4
gen m1profits2013=mprofits2013
gen a1profits2021=aprofits2021
egen a1profits2016=rowmean(aprofits2016 aprofits_1_2015 aprofits_2_2015 aprofits2014)
gen a1profits2013=aprofits2013
* all profits conditional on survival
gen c1aprofits2013=caprofits2013
egen c1aprofits2016=rowmean(caprofits2016 caprofits_1_2015 caprofits_2_2015 caprofits2014)
gen c1aprofits2021=caprofits2021


***** Profits 
** Short-term profits into real dollars
** they were already converted into baseline CFA
gen bl_mprofit=win_bl_profits_lm*(111.7/100)/550.5
gen bl_aprofit=win_bl_total_profits*(111.7/100)/550.5
gen mprofit_fu1=win_fu1_profits_lm*(111.7/100)/550.5
gen mprofit_fu2=win_fu2_profits_lm*(111.7/100)/550.5
gen mprofit_fu3=win_fu3_profits_lm*(111.7/100)/550.5
gen mprofit_fu4=win_fu4_profits_lm*(111.7/100)/550.5
gen aprofit_fu1=win_fu1_total_profits*(111.7/100)/550.5
gen aprofit_fu2=win_fu2_total_profits*(111.7/100)/550.5
gen aprofit_fu3=win_fu3_total_profits*(111.7/100)/550.5
gen aprofit_fu4=win_fu4_total_profits*(111.7/100)/550.5

* Profits ready to stack and reshape 
* profits in main business 
for num 1/4: gen mainprofX=mprofit_fuX
gen mainprof5=mainbusi_totprof_lastmonth_as_wu
replace mainprof5=0 if mainprof5==. & selfemployed==0
* all businesses
for num 1/4: gen totalprofX=aprofit_fuX
gen totalprof5=lastmonthprof
replace totalprof5=0 if totalprof5==. & selfemployed==0
* all businesses conditional on survival 
for num 1/4: gen ctotalprofX=totalprofX if fuX_has_business==1
gen ctotalprof5=totalprof5 if survival2021==1


***** Sales
*** Note: sales in other businesses not asked in short-run or baseline
*** Short-term sales into real dollars
gen bl_msales=win_bl_sales_lm*(111.7/100)/550.5
gen msales_fu1=win_fu1_sales_lm*(111.7/100)/550.5
gen msales_fu2=win_fu2_sales_lm*(111.7/100)/550.5
gen msales_fu3=win_fu3_sales_lm*(111.7/100)/550.5
gen msales_fu4=win_fu4_sales_lm*(111.7/100)/550.5

* Sales ready to stack and reshape
* Sales in main business 
for num 1/4: gen mainsalesX=msales_fuX
gen mainsales5=mainbusi_totsale_lastmonth_as_wu
replace mainsales5=0 if mainsales5==. & selfemployed==0
* note total sales in all businesses only available for long-run 
gen totalsales5=lastmonthsales
* main business and all businesses conditional on survival 
for num 1/4: gen cmainsalesX=mainsalesX  if fuX_has_business==1
gen cmainsales5=mainsales5 if survival2021==1
gen ctotalsales5=totalsales5 if survival2021==1


* Index of Profits and Sales in Main Business
foreach var in bl_mprofit bl_msales mainprof1 mainprof2 mainprof3 mainprof4 mainprof5 mainsales1 mainsales2 mainsales3 mainsales4 mainsales5 {
	sum `var' if assign_control==1
	gen z_`var'=(`var'-r(mean))/r(sd)
	label var z_`var' "Z-score of `var'"
}
egen bl_psindex=rowmean(z_bl_mprofit z_bl_msales)
label var bl_psindex "Baseline Profits and Sales index"
for num 1/5: egen psindexX=rowmean(z_mainprofX z_mainsalesX)
for num 1/5: label var psindexX "Profit and Sales index in round X"


**** Total income 
*** Profits from all businesses plus paid work, farming, retirement income, investment income
gen otherincome=othact_totrev_lastmonth_as_wu
gen allincome5=lastmonthprof+otherincome 
* other income was  in 2014 CFA - convert to 2021 USD
for num 1/4: gen oincome_fuX=win_fuX_otherincome*111.7/550.5
for num 1/4: gen allincomeX=totalprofX+oincome_fuX

***Employment
*** Total number of employees (unconditional)
gen mainemployees=mainbusi_num_employee_as
replace mainemployees=0 if mainemployees==. & selfemployed==0
label var mainemployees "Number of employees in main firm"
gen mainpaidemployees=mainbusi_num_paidemployee_as
replace mainpaidemployees=0 if mainpaidemployees==. & selfemployed==0
label var mainpaidemployees "Number of paid employees in main firm"
gen allemployees=mainbusi_num_employee_ip
replace allemployees=mainbusi_num_employee_ip+num_emp_othcomp_ip if num_emp_othcomp_ip~=.
replace allemployees=0 if response_rate_ip==1 & selfemployed==0 & allemployees==.
label var allemployees "Employees in all businesses"
gen employ2013=bl_no_workers
egen employ2016=rowmean(fu1_no_workers fu2_no_workers fu3_no_workers fu4_no_workers)
gen employ2021=mainemployees
winsor2 employ2013, suffix(_w) cuts(1 99)
winsor2 employ2016, suffix(_w) cuts(1 99)
winsor2 employ2021, suffix(_w) cuts(1 99)
rename employ2013_w w_employ2013
rename employ2016_w w_employ2016
rename employ2021_w w_employ2021
* Winsorize employment to reduce outlier impacts
winsor2 mainemployees, suffix(_w) cuts(1 99)
winsor2 allemployees, suffix(_w) cuts(1 99)
gen allpaidemployees=mainpaidemployees
replace allpaidemployees=mainpaidemployees+num_paidemp_othcomp_ip if num_paidemp_othcomp_ip~=.
replace allpaidemployees=0 if response_rate_ip==1 & selfemployed==0 & allpaidemployees==.
* Winsorize employment to reduce outlier impacts
winsor2 mainpaidemployees, suffix(_w) cuts(1 99)
winsor2 allpaidemployees, suffix(_w) cuts(1 99)
winsor2 fu1_no_workers, suffix(_w) cuts(1 99)
winsor2 fu2_no_workers, suffix(_w) cuts(1 99)
winsor2 fu3_no_workers, suffix(_w) cuts(1 99)
winsor2 fu4_no_workers, suffix(_w) cuts(1 99)
gen memployees5=mainemployees_w 
for num 1/4: gen memployeesX=fuX_no_workers_w


***Capital Stock
* asset values 
destring asset_val_furn_ip asset_val_oth_ip asset_val_stock_ip, force replace
foreach var of varlist asset_val_mach_ip asset_val_othtools_ip asset_val_vehi_ip asset_val_furn_ip asset_val_land_ip asset_val_oth_ip asset_val_stock_ip {
	replace `var'=0 if `var'==. & asset_mach_ip~=.
	replace `var'=0 if `var'==. & selfemployed==0
}
sum asset_val_mach_ip asset_val_othtools_ip asset_val_vehi_ip asset_val_furn_ip asset_val_land_ip asset_val_oth_ip asset_val_stock_ip
gen totassets=asset_val_mach_ip + asset_val_othtools_ip + asset_val_vehi_ip + asset_val_furn_ip + asset_val_land_ip + asset_val_oth_ip + asset_val_stock_ip
gen totasset2=totassets-asset_val_land_ip
foreach var of varlist totassets totasset2 {
	* convert to USD
	replace `var'=`var'/550.5
	winsor2 `var', suffix(_w) cuts(1 99)
}
sum totassets_w totasset2_w
* winsorize baseline and 2016 capital and convert into 2021 USD 
replace bl_kstock2=bl_kstock2*(111.7/100)/550.5
replace fu4_kstock2=fu4_kstock2*(111.7/100)/550.5
winsor2 bl_kstock2, suffix(_w) cuts(1 99)
winsor2 fu4_kstock2, suffix(_w) cuts(1 99)
* check coded as 0 if firms are closed
replace fu4_kstock2_w=0 if fu4_kstock2_w==. & survival2016==0
replace totasset2_w=0 if totasset2_w==. & survival2021==0
gen kstock2013=bl_kstock2_w
gen kstock2016=fu4_kstock2_w
gen kstock2021=totasset2_w
gen bl_kstock=win_bl_k_stock*(111.7/100)/550.5
* dummy out missing baseline capital stock
gen baseK=bl_kstock2_w
gen miss_baseK=baseK==.
replace baseK=0 if miss_baseK==1
* capital stock for regressions
gen capital5=totasset2_w
gen capital4=fu4_kstock2_w

*** Business practices - construct binary variables, then proportion of these used
* Business practices coded the same as in previous rounds 
* recode 2 to 0 for binary variables
replace company_budget_ip=0 if company_budget_ip==2
replace company_sales_obj_ip=0 if company_sales_obj_ip==2
foreach var of varlist company_visit_opp_ip-company_rd_ip {
	gen bin1_`var'=cond((`var'>=2),1,0) if `var'~=.
}
egen bpindex5=rowmean(bin1_company_visit_opp_ip-bin1_company_rd_ip company_budget_ip company_sales_obj_ip)
replace bpindex5=0 if bpindex5==. & selfemployed==0
for num 2/4: rename bpindex_fuX bpindexX

*** Self-efficacy 
sum self_eff_A_ip self_eff_B_ip self_eff_C_ip self_eff_D_ip self_eff_E_ip self_eff_F_ip self_eff_G_ip self_eff_H_ip self_eff_I_ip
alpha self_eff_A_ip self_eff_B_ip self_eff_C_ip self_eff_D_ip self_eff_E_ip self_eff_F_ip self_eff_G_ip self_eff_H_ip self_eff_I_ip, item
egen selfefficacy=rowmean(self_eff_A_ip self_eff_B_ip self_eff_C_ip self_eff_D_ip self_eff_E_ip self_eff_F_ip self_eff_G_ip self_eff_H_ip self_eff_I_ip)
gen selfeff5=selfefficacy
gen selfeff4=fu4_selfefficacy

*** Personal Initiative
* check PI Cronback alpha
alpha persoinit_b_as persoinit_f_as persoinit_h_as persoinit_j_as persoinit_l_as, item
gen piindex5=pi_index_as 
for num 1/4: gen piindexX=PIss_fuX
replace PIss_bl=0 if PIss_bl==.

** A index ()
foreach var in piindex5 piindex4 piindex3 piindex2 piindex1 selfeff4 selfeff5 bl_selfefficacy PIss_bl ///
bpindex5 bpindex4 bpindex3 bpindex2  bl_business_practice  {
	sum `var' if assign_control==1
	gen z_`var'=(`var'-r(mean))/r(sd)
	label var z_`var' "Z-score of `var'"
}
egen Aind5=rowmean(z_piindex5 z_selfeff5  z_bpindex5)
egen Aind4=rowmean(z_piindex4 z_selfeff4  z_bpindex4)
egen bl_Aind=rowmean(z_PIss_bl z_bl_selfefficacy  z_bl_business_practice)


** Subsamples for Table 3
* Is it just low profit firms?
gen lowprofit=bl_aprofit<100
bysort bl_female: sum lowprofit
* 57% of women and 44% of men are low profit 
* Other hh member runs a business
gen otherhhbus=cond(hh_oth_compown_ip==1,1,0) if hh_oth_compown_ip~=.

*** Supplementary Outcomes
*** Number of businesses and more than one business
gen numberotherfirms=othbusi_num_company_as
replace numberotherfirms=0 if numberotherfirms==. & selfemployed==0
label var numberotherfirms "Number of other firms operated"
** More than one firm
gen morethanonefirm=cond(numberotherfirms>0,1,0) if numberotherfirms~=.
label var morethanonefirm "Owns more than one firm"
sum numberotherfirms morethanonefirm

*** Other measures of profits and sales for appendix robustness
** Log profits and sales in all businesses 
gen logprof=log(totalprof5)
gen logsales=log(totalsales5)
gen bl_logprof=log(bl_aprofit)
* note: only main firm sales available at baseline
gen bl_logsales=log(bl_msales)
* use all profits at baseline as baseline measure for best and worst profits 
gen bl_bestmonthprof=bl_aprofit
gen bl_worstmonthprof=bl_aprofit
gen bl_bestmonthsales=bl_msales 
gen bl_worstmonthsales=bl_msales

** 2019 measures
gen profb2019=totprof_bestm19_best_ip_usd
replace profb2019=profb2019+totprofoth_bestm19_best_ip_usd if totprofoth_bestm19_best_ip_usd~=.
gen profw2019=totprof_worstm19_best_ip_usd
replace profw2019=profw2019+totprofoth_worstm19_best_ip_usd if totprofoth_worstm19_best_ip_usd~=.
gen salesb2019=totsal_bestm19_best_ip_usd
replace salesb2019=salesb2019+totsaloth_bestm19_best_ip_usd if totsaloth_bestm19_best_ip_usd~=.
gen salesw2019=totsal_worstm19_best_ip_usd
replace salesw2019=salesw2019+totsaloth_worstm19_best_ip_usd if totsaloth_worstm19_best_ip_usd~=.

foreach var in salesb2019 salesw2019 profb2019 profw2019 {
	replace `var'=0 if `var'==. & selfemployed==0 & response_rate_ip==1
	winsor2 `var', suffix(_w) cuts(1 99)
}
** convert into Sept 2021 USD 
foreach var in salesb2019_w salesw2019_w profb2019_w profw2019_w {
	replace `var'=`var'*(111.7/102.7)
}
gen bl_profb2019=bl_aprofit
gen bl_profw2019=bl_aprofit
gen bl_salesb2019=bl_msales 
gen bl_salesw2019=bl_msales 
*** Indices of Additional Profit and Sales Measures 
foreach var in bestmonthprof worstmonthprof profb2019 profw2019 bestmonthsales worstmonthsales salesb2019 salesw2019  {
	sum `var' if assign_control==1
	gen z_`var'=(`var'-r(mean))/r(sd)
	label var z_`var' "Z-score of `var'"
	sum bl_`var' if assign_control==1
	gen z_bl_`var'=(bl_`var'-r(mean))/r(sd)
	label var z_bl_`var' "Z-score of bl_`var'"
}
egen otherprofindex=rowmean(z_bestmonthprof z_worstmonthprof z_profb2019 z_profw2019)
egen bl_otherprofindex=rowmean(z_bl_bestmonthprof z_bl_worstmonthprof z_bl_profb2019 z_bl_profw2019)
egen othersalesindex=rowmean(z_bestmonthsales z_worstmonthsales z_salesb2019 z_salesw2019)
egen bl_othersalesindex=rowmean(z_bl_bestmonthsales z_bl_worstmonthsales z_bl_salesb2019 z_bl_salesw2019)


*** Robust profit types
** assume all attritors earn maximum of their profits in any previous round
egen maxprof=rowmax(totalprof1 totalprof2 totalprof3 totalprof4 bl_aprofit)
gen robustprof1=totalprof5
replace robustprof1=maxprof if robustprof1==.
** assume all attritors earn average of profits for those who answer only once
gen robustprof2=totalprof5
replace robustprof2=167 if robustprof2==.
*** IF All attritors are closed 
gen robustprof3 =totalprof5
replace robustprof3=0 if robustprof3==.
*** lee bounds 
gen reporttotalprof=totalprof5~=.
tab assign_group reporttotalprof 
* 36 more PI firms and 23 more trad firms report profits than control
* Lower bound: assume these are all highest earning firms
set seed 139
set sortseed 234
egen rankprof=rank(totalprof5), by(assign_group) unique
gen lblower=totalprof5 
replace lblower=. if rankprof>426
gen lbupper=totalprof5 
replace lbupper=. if assign_group==1 & rankprof<=23
replace lbupper=. if assign_group==2 & rankprof<=36 

*** Innovation
gen pivot1=cond((change_loc_ip==1|change_ind_ip==1),1,0) if change_loc_ip~=.
replace pivot1=0 if pivot1==. & selfemployed==0
label var pivot1 "Changed location or industry"
gen pivot2=cond(change_activity_ip==1,1,0) if change_activity_ip~=.
replace pivot2=0 if pivot2==. &  selfemployed==0
label var pivot2 "Pivoted"
gen prodinnovate=cond(newproduct_ip==1,1,0) if newproduct_ip~=.
replace prodinnovate=0 if prodinnovate==. & selfemployed==0
label var prodinnovate "Introduced new product"
gen prodinvent1=cond(newproduct_origins_ip==1,1,0) if prodinnovate~=.
replace prodinvent1=0 if prodinvent1==. & selfemployed==0
label var prodinvent1 "New product based on own ideas"
gen prodinvent2=cond(newproduct_origins_ip<=2,1,0) if prodinnovate~=.
replace prodinvent2=0 if prodinvent2==. & selfemployed==0
label var prodinvent2 "New product based on own ideas or copied"
egen innovateindex=rowmean(pivot1 pivot2 prodinnovate prodinvent1 prodinvent2)
label var innovateindex "Innovation Index"

*** Digitalization
gen digitaltech=cond(company_use_newtech_ip<=2,1,0) if company_use_newtech_ip~=.
replace digitaltech=0 if digitaltech==. & selfemployed==0
label var digitaltech "Increased use of digital technology during Covid"
gen website=cond(company_website_ip==1,1,0) if company_website_ip~=.
replace website=0 if website==. & selfemployed==0
label var website "Has a company website"
gen socialmedia=cond(company_socialmedia_ip==1,1,0) if company_socialmedia_ip~=.
replace socialmedia=0 if socialmedia==. & selfemployed==0
label var socialmedia "Uses social media for marketing"
gen mobilemoney=cond( company_mobilemoney_ip==1,1,0) if  company_mobilemoney_ip~=.
replace mobilemoney=0 if mobilemoney==. & selfemployed==0
label var mobilemoney "Accepts mobile money"
egen digitalindex=rowmean(digitaltech website socialmedia mobilemoney)
label var digitalindex "Digitalindex"

* Maximum amount could borrow 
destring loan_max_amount_ip, force replace
replace loan_max_amount_ip=0 if loan_max_amount_ip==. & selfemployed==0
* convert to USD and winsorize
gen maxloan=loan_max_amount_ip/550.5
winsor2 maxloan, suffix(_w) cuts(1 99)

*** Components of Capital Stock
foreach var of varlist asset_val_mach_ip asset_val_othtools_ip asset_val_vehi_ip asset_val_furn_ip asset_val_land_ip asset_val_oth_ip asset_val_stock_ip {
	* convert to USD
	replace `var'=`var'/550.5
	winsor2 `var', suffix(_w) cuts(1 99)
}


*** Variables for heterogeneity in women sample
gen belowmeanedu=bl_years_schooling<9
gen notsoledecisionrev=1-soledecisionrevenue
gen notsoledecisionexp=1-soledecisionhhexp
foreach var of varlist notsoledecisionrev notsoledecisionexp lookafterothers belowmeanedu notmarried {
	gen assign_ent_`var'=assign_ent*`var'
	gen assign_man_`var'=assign_man*`var'
	gen bl_aprofit_`var'=bl_aprofit*`var'
}
	
	save "$final/Togoanalysisdata.dta", replace